#!/usr/bin/env python

#-------------------------------------------------------------------
# Objectives
#------------------------------------------------------------------

# This table contains an archive of parameter values that have been 
# used for different ORCHIDEE-CAN and ORCHIDEE-CN-CAN revisions.

# Parameter values should correspond to one of the PFTs defined in 
# configuration_template. If the PFT is absent from the table below
# the default value specified in the code will be used. If the PFT 
# gets a value of -9999 this PFT will be added to the run.def. It 
# indicates that that specific parameter is not used for PFT under 
# consideration. As the parameter values in the code are unreliable
# for ORCHIDEE-CN-CAN, the better option is to specify the value
# you want to use rather than relying on the default values.

# CODING GUIDELINE: variable names written in capitals are variables
# that will end up in the run.defs

#-------------------------------------------------------------------
# Configure the individual PFTs
#-------------------------------------------------------------------

# Parameter names and the revision number when they were removed. 
removed = [\
           ['PSI_SOIL_TUNE','r4916'],
           ['HEIGHT_INIT_MAX','r5800'],
           ['SLA','r5966'] ,
           ['H_FIRST','r6098'],
           ['COPPICE_DIAMETER','r6383'],
           ['TAU_LEAF','r6742'],
           ['TAU_ROOT','r6742'],
           ['TAU_SAP','r6742'],
           ['HEIGHT_INIT_MIN','r6757'],
           ['HEIGHT_INIT_MAX','r6757'],
           ['LEAFAGECRIT','r6886'],
           ['PIPE_TUNE1','r6922'],
           ['PIPE_TUNE_EXP_COEFF','r6922'],
           ['MAINT_RESP_SLOPE_A','r6956'],
           ['VCMAX25','r7011'],
           ['NMAXTREES','r7549'],
           ['ALPHA_RDI_UPPER','r7549'],
           ['ALPHA_RDI_LOWER','r7549'],
           ['BETA_RDI_UPPER','r7549'],
           ['BETA_RDI_LOWER','r7549'],
           ['A1','r7634'],
           ['B1','r7634'],
           ['ALLOC_MAX','r7676'],
           ['ALLOC_MIN','r7676'],
           ['ALPHA_SELF_THINNING','r7676'],
           ['ARJV','r7676'],
           ['BETA_SELF_THINNING','r7676'], 
           ['BGRD_REF_VIS','r7676'],
           ['BGRD_REF_NIR','r7676'],
           ['B_RDI_LOWER_UNMAN','r7676'],
           ['B_RDI_UPPER_UNMAN','r7676'],
           ['CN_LEAF_PRESCRIBED','r7676'],
           ['DEATH_DF','r7676'],
           ['DIA_INIT_MAX','r7676'],
           ['DIA_INIT_MIN','r7676'],
           ['FCN_ROOT','r7676'],
           ['FCN_WOOD','r7676'],
           ['FRAC_GROWTHRESP','r7676'],
           ['FRUIT_ALLOC','r7676'],
           ['FUELWOOD_DIAMETER','r7676'],
           ['GDD_SENESCENCE','r7676'],
           ['GPP_TO_LABILE','r7676'],
           ['HARVEST_RATIO','r7676'],
           ['HEIGHT_INIT','r7676'],
           ['HUM_MIN_TIME','r7676'],
           ['K_BELOWGROUND','r7678'],
           ['K_LEAF','r7678'],
           ['K_ROOT','r7678'],
           ['K_SAP','r7678'],
           ['LABILE_RESERVE','r7678'],
           ['LAI_TOP','r7678'],
           ['LARGEST_TREE_DIA','r7678'],
           ['LEAFFALL','r7678'],
           ['LEAF_AGE_CRIT_COEFF1','r7678'],
           ['LEAF_AGE_CRIT_COEFF2','r7678'],
           ['LEAF_AGE_CRIT_COEFF3','r7678'],
           ['LEAF_AGE_CRIT_TREF','r7678'],
           ['LEAF_PSD_NIR','r7678'],
           ['LEAF_PSD_VIS','r7678'],
           ['LEAF_SSA_NIR','r7678'],
           ['LEAF_SSA_VIS','r7678'],
           ['LONGEVITY_LEAF','r7678'],
           ['LONGEVITY_ROOT','r7678'],
           ['NCDGDD_TEMP','r7684'],
           ['NGD_CRIT','r7684'],
           ['NOSENESCENCE_HUM','r7684'],
           ['NUE_OPT','r7684'],
           ['PHENO_GDD_CRIT_C','r7684'],
           ['PHENO_TYPE','r7684'],
           ['PIPE_DENSITY','r7684'],
           ['PIPE_TUNE2','r7684'],
           ['PIPE_TUNE3','r7684'],
           ['PSI_50','r7684'],
           ['PSI_LEAF','r7684'],
           ['PSI_ROOT','r7684'],
           ['RECRUITMENT_PFT','r7684'],
           ['RESIDENCE_TIME','r7684'],
           ['R_FROOT','r7684'],
           ['SENESCENCE_TEMP_C','r7684'],
           ['SENESCENCE_TYPE','r7684'],
           ['SENESCENSE_RESERVE','r7684'],
           ['SLAINIT','r7684'],
           ['SRL','r7684'],
           ['TPHOTO_MIN','r7684'],
           ['TPHOTO_MIN_C','r7684'],
           ['TREE_FF','r7684'],
           ['VMAX_UPTAKE_NH4','r7684'],
           ['VMAX_UPTAKE_NO3','r7684'],
           ['ALPHA_LL','r7689'],
           ['COEFF_MAINT_INIT','r7689'],
           ['IS_BOREAL','r7689'],
           ['IS_TEMPERATE','r7689'],
           ['LONGEVITY_SAP','r7689'],
           ['K_LATOSA_MAX','r7689'],
           ['K_LATOSA_MIN','r7689'],
           ['PHENO_MODEL','r7689'],
           ['HYDROL_HUMCSTE','r7689'],
           ['MAINT_RESP_SLOPE_C','r7689'],
           ['MAINT_RESP_SLOPE_B','r7689'],
           \
]
# Parameter names and the revision number when they were added.
added = [\
         ['SRL','r4916'],
         ['R_FROOT','r4916'],
         ['PSI_ROOT','r4916'],
         ['SLAINIT','r5966'],
         ['LONGEVITY_LEAF','r6742'],
         ['LONGEVITY_ROOT','r6742'],
         ['LONGEVITY_SAP','r6742'],
         ['HEIGHT_INIT','r6757'],
         ['NCDGDD_TEMP','r6762'],
         ['SENESCENCE_TEMP_C','r6762'],
         ['LEAF_AGE_CRIT_TREF','r6900'],
         ['LEAF_AGE_CRIT_COEFF1','r6900'],
         ['LEAF_AGE_CRIT_COEFF2','r6900'],
         ['LEAF_AGE_CRIT_COEFF3','r6900'],
         ['MAINT_RESP_SLOPE_A','r6947'],
         ['MAINT_RESP_SLOPE_B','r6947'],
         ['MAINT_RESP_SLOPE_C','r6947'],
         ['PERCENT_THROUGHFALL_PFT','r6977'],
         ['MAINT_RESP_SLOPE_B','r7244'],
         ['MAINT_RESP_SLOPE_C','r7244'],
         ['VMAX_UPTAKE_NH4','r7355'],
         ['VMAX_UPTAKE_NO3','r7355'],
         ['NUE_OPT','r7568'],
         ['A1','r7568'],
         ['B1','r7568'],
         ['B_RDI_LOWER_UNMAN','r7568'],
         ['B_RDI_UPPER_UNMAN','r7568'],
         ['ALPHA_LL','r7690'],
         ['COEFF_MAINT_INIT','r7690'],
         ['IS_BOREAL','r7690'],
         ['IS_TEMPERATE','r7690'],
         ['LONGEVITY_SAP','r7690'],
         ['K_LATOSA_MAX','r7690'],
         ['K_LATOSA_MIN','r7690'],
         ['PHENO_MODEL','r7690'],
         ['HYDROL_HUMCSTE','r7690'],
         ['MAINT_RESP_SLOPE_C','r7690'],
         ['MAINT_RESP_SLOPE_B','r7690'],
         \
]

# Archive of parameter names and their values.       
header = ['date','mtc', 'pft', 'species, genus or biome', 'parameter name','unit', 'parameter value', 'revision number','origin']
parameter = [\
             [20150303,'BareSoil','SoilBare','Global','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','IS_TEMPERATE','y/n','FALSE','r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','IS_TEMPERATE','y/n','TRUE','r2566',''],
             [20150303,'BareSoil','SoilBare','Global','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','IS_BOREAL','y/n','TRUE','r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','IS_BOREAL','y/n','FALSE','r2566',''],
             [20150303,'BareSoil','SoilBare','Global','VCMAX25','umol m-2s-1',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','VCMAX25','umol m-2s-1',33,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','VCMAX25','umol m-2s-1',45,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','VCMAX25','umol m-2s-1',79,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','VCMAX25','umol m-2s-1',87,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','VCMAX25','umol m-2s-1',90,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','VCMAX25','umol m-2s-1',61,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','VCMAX25','umol m-2s-1',79,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','VCMAX25','umol m-2s-1',39,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','VCMAX25','umol m-2s-1',39,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','VCMAX25','umol m-2s-1',77,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','VCMAX25','umol m-2s-1',77,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','VCMAX25','umol m-2s-1',40,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','VCMAX25','umol m-2s-1',65,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','VCMAX25','umol m-2s-1',137,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','VCMAX25','umol m-2s-1',77,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','VCMAX25','umol m-2s-1',69,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','VCMAX25','umol m-2s-1',50,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','VCMAX25','umol m-2s-1',87,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','VCMAX25','umol m-2s-1',77,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','VCMAX25','umol m-2s-1',77,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','VCMAX25','umol m-2s-1',40,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','VCMAX25','umol m-2s-1',80,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','VCMAX25','umol m-2s-1',80,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','VCMAX25','umol m-2s-1',50,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','VCMAX25','umol m-2s-1',50,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','VCMAX25','umol m-2s-1',50,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','VCMAX25','umol m-2s-1',60,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','ARJV','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ARJV','unitless',2.1,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ARJV','unitless',2.5,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ARJV','unitless',2.04,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ARJV','unitless',2.48,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ARJV','unitless',1.72,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ARJV','unitless',1.91,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','ARJV','unitless',2.04,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ARJV','unitless',2.22,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ARJV','unitless',2.22,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ARJV','unitless',2.18,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ARJV','unitless',2.18,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ARJV','unitless',2.08,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ARJV','unitless',2.04,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ARJV','unitless',1.4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','ARJV','unitless',2.18,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ARJV','unitless',2.28,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ARJV','unitless',2.48,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ARJV','unitless',2.09,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ARJV','unitless',2.18,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ARJV','unitless',2.18,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','ARJV','unitless',2.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','ARJV','unitless',2.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','ARJV','unitless',2.0,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','ARJV','unitless',2.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','ARJV','unitless',2.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','ARJV','unitless',2.0,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','ARJV','unitless',2.0,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','ALPHA_LL','mol e- (mol photon)-1',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_LL','mol e- (mol photon)-1',0.53,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALPHA_LL','mol e- (mol photon)-1',0.53,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.5,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.43,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','TPHOTO_MIN_C','degrees C',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TPHOTO_MIN_C','degrees C',2.0,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TPHOTO_MIN_C','degrees C',2.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TPHOTO_MIN_C','degrees C',-3.0,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','TPHOTO_MIN_C','degrees C',-3.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','TPHOTO_MIN_C','degrees C',-4.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','TPHOTO_MIN_C','degrees C',-3.25,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','TPHOTO_MIN_C','degrees C',13.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','TPHOTO_MIN_C','degrees C',-6.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','TPHOTO_MIN_C','degrees C',-5.0,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','TPHOTO_MIN_C','degrees C',13.0,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','SLA','m2 gC-1',0.03,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','SLA','m2 gC-1',0.029,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','SLA','m2 gC-1',0.037,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','SLA','m2 gC-1',0.0079,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','SLA','m2 gC-1',0.0114,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','SLA','m2 gC-1',0.005,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','SLA','m2 gC-1',0.0072,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','SLA','m2 gC-1',0.0079,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','SLA','m2 gC-1',0.0137,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','SLA','m2 gC-1',0.0137,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SLA','m2 gC-1',0.0288,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','SLA','m2 gC-1',0.0288,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','SLA','m2 gC-1',0.033,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','SLA','m2 gC-1',0.0286,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','SLA','m2 gC-1',0.0256,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','SLA','m2 gC-1',0.0288,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','SLA','m2 gC-1',0.0073,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','SLA','m2 gC-1',0.008,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','SLA','m2 gC-1',0.0066,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','SLA','m2 gC-1',0.0288,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','SLA','m2 gC-1',0.0288,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','SLA','m2 gC-1',0.0218,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','SLA','m2 gC-1',0.026,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','SLA','m2 gC-1',0.026,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','SLA','m2 gC-1',0.026,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','SLA','m2 gC-1',0.04,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','SLA','m2 gC-1',0.04,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','SLA','m2 gC-1',0.04,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','TAU_ROOT','days',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TAU_ROOT','days',280,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TAU_ROOT','days',280,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TAU_ROOT','days',275,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','TAU_ROOT','days',224,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','TAU_ROOT','days',275,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','TAU_ROOT','days',326,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','TAU_ROOT','days',275,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TAU_ROOT','days',191,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','TAU_ROOT','days',191,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TAU_ROOT','days',296,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','TAU_ROOT','days',224,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','TAU_ROOT','days',368,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TAU_ROOT','days',280,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','TAU_ROOT','days',280,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','TAU_ROOT','days',360,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','TAU_ROOT','days',310,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','TAU_ROOT','days',310,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','TAU_ROOT','days',310,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','TAU_ROOT','days',280,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','TAU_ROOT','days',280,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','TAU_LEAF','days',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TAU_LEAF','days',645,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TAU_LEAF','days',231,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TAU_LEAF','days',1283,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','TAU_LEAF','days',720,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','TAU_LEAF','days',1670,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','TAU_LEAF','days',1460,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','TAU_LEAF','days',1283,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TAU_LEAF','days',677,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','TAU_LEAF','days',677,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TAU_LEAF','days',146,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','TAU_LEAF','days',146,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','TAU_LEAF','days',183,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','TAU_LEAF','days',183,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','TAU_LEAF','days',183,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','TAU_LEAF','days',146,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TAU_LEAF','days',1660,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','TAU_LEAF','days',1160,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','TAU_LEAF','days',2160,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TAU_LEAF','days',146,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','TAU_LEAF','days',146,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','TAU_LEAF','days',180,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','TAU_LEAF','days',265,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','TAU_LEAF','days',200,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','TAU_LEAF','days',135,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','TAU_LEAF','days',1000,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','TAU_LEAF','days',1000,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','TAU_LEAF','days',1000,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','TAU_SAP' ,'days',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TAU_SAP' ,'days',7300,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TAU_SAP' ,'days',7300,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TAU_SAP' ,'days',15148,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','TAU_SAP' ,'days',13870,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','TAU_SAP' ,'days',15148,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','TAU_SAP' ,'days',16425,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','TAU_SAP' ,'days',15148,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','TAU_SAP' ,'days',11680,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','TAU_SAP' ,'days',13870,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','TAU_SAP' ,'days',730,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','TAU_SAP' ,'days',730,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','TAU_SAP' ,'days',730,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','TAU_SAP' ,'days',730,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','TAU_SAP' ,'days',730,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','TAU_SAP' ,'days',730,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','GPP_TO_LABILE','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','GPP_TO_LABILE','unitless',1,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','HYDROL_HUMCSTE','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','HYDROL_HUMCSTE','unitless',1.0,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','HYDROL_HUMCSTE','unitless',4.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','HYDROL_HUMCSTE','unitless',4.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','HYDROL_HUMCSTE','unitless',4.0,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','HYDROL_HUMCSTE','unitless',4.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','HYDROL_HUMCSTE','unitless',4.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','HYDROL_HUMCSTE','unitless',4.0,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','HYDROL_HUMCSTE','unitless',4.0,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','NGD_CRIT','degrees C',17,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PHENO_MODEL','unitless','none','r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PHENO_MODEL','unitless','none','r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PHENO_MODEL','unitless','none','r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PHENO_TYPE','unitless',1,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PHENO_TYPE','unitless',1,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PHENO_TYPE','unitless',1,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PHENO_GDD_CRIT_C','K',410,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PHENO_GDD_CRIT_C','K',360,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PHENO_GDD_CRIT_C','K',450,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','HUM_MIN_TIME','days',35,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','HUM_MIN_TIME','days',50,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','HUM_MIN_TIME','days',75,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','SENESCENCE_TYPE','unitless','none','r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','SENESCENCE_TYPE','unitless','none','r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','SENESCENCE_TYPE','unitless','none','r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','GDD_SENESCENCE','K',1100,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','GDD_SENESCENCE','K',1600,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','GDD_SENESCENCE','K',2500,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SENESCENCE_TEMP_C','degrees C',16.57,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','SENESCENCE_TEMP_C','degrees C',16.57,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','SENESCENCE_TEMP_C','degrees C',16.57,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','SENESCENCE_TEMP_C','degrees C',16.57,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','SENESCENCE_TEMP_C','degrees C',16.57,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','SENESCENCE_TEMP_C','degrees C',16.57,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','SENESCENCE_TEMP_C','degrees C',14.61,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','SENESCENCE_TEMP_C','degrees C',14.61,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','SENESCENCE_TEMP_C','degrees C',6,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','SENESCENCE_TEMP_C','degrees C',9.38,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','SENESCENCE_TEMP_C','degrees C',9.38,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','SENESCENCE_TEMP_C','degrees C',5.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','SENESCENCE_TEMP_C','degrees C',10.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','SENESCENCE_TEMP_C','degrees C',12.0,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','SENESCENCE_TEMP_C','degrees C',13.0,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','HARVEST_RATIO','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','HARVEST_RATIO','unitless',0.5,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','HARVEST_RATIO','unitless',0.5,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','HARVEST_RATIO','unitless',0.5,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LEAFFALL','days',5.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LEAFFALL','days',15.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LEAFFALL','days',15.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LEAFFALL','days',15.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LEAFFALL','days',15.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LEAFFALL','days',15.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LEAFFALL','days',15.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAFFALL','days',2.5,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LEAFFALL','days',2.5,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAFFALL','days',5.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LEAFFALL','days',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LEAFAGECRIT','days',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LEAFAGECRIT','days',730,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LEAFAGECRIT','days',730,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LEAFAGECRIT','days',730,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LEAFAGECRIT','days',910,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAFAGECRIT','days',180,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LEAFAGECRIT','days',120,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LEAFAGECRIT','days',120,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LEAFAGECRIT','days',120,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LEAFAGECRIT','days',90,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LEAFAGECRIT','days',90,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LEAFAGECRIT','days',90,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','RESIDENCE_TIME','years',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','RESIDENCE_TIME','years',1000,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','RESIDENCE_TIME','years',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','RESIDENCE_TIME','years',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','RESIDENCE_TIME','years',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','RESIDENCE_TIME','years',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','RESIDENCE_TIME','years',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','RESIDENCE_TIME','years',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','DEATH_DF','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','DEATH_DF','unitless',1,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','DEATH_DF','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','DEATH_DF','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','DEATH_DF','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','DEATH_DF','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','DEATH_DF','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','DEATH_DF','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PIPE_DENSITY','gC m-3',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_DENSITY','gC m-3',287458,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PIPE_DENSITY','gC m-3',268753,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PIPE_DENSITY','gC m-3',208333,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PIPE_DENSITY','gC m-3',235000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PIPE_DENSITY','gC m-3',190000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PIPE_DENSITY','gC m-3',208333,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PIPE_DENSITY','gC m-3',480000,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PIPE_DENSITY','gC m-3',480000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PIPE_DENSITY','gC m-3',238000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PIPE_DENSITY','gC m-3',238000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PIPE_DENSITY','gC m-3',334000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PIPE_DENSITY','gC m-3',300000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PIPE_DENSITY','gC m-3',176000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PIPE_DENSITY','gC m-3',238000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PIPE_DENSITY','gC m-3',195000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PIPE_DENSITY','gC m-3',190000,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_DENSITY','gC m-3',238000,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PIPE_DENSITY','gC m-3',238000,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PIPE_DENSITY','gC m-3',248750,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PIPE_DENSITY','gC m-3',200000,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','TREE_FF','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','TREE_FF','unitless',0.9,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','TREE_FF','unitless',0.6,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TREE_FF','unitless',0.75,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','TREE_FF','unitless',0.75,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','TREE_FF','unitless',0.75,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','TREE_FF','unitless',0.7,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','TREE_FF','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','TREE_FF','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','TREE_FF','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','TREE_FF','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','TREE_FF','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','TREE_FF','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PIPE_TUNE1','m' ,-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_TUNE1','m' ,200,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PIPE_TUNE1','m' ,200,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PIPE_TUNE1','m' ,83,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PIPE_TUNE1','m' ,97,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PIPE_TUNE1','m' ,97,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PIPE_TUNE1','m' ,54,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PIPE_TUNE1','m' ,83,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PIPE_TUNE1','m' ,113,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PIPE_TUNE1','m' ,113,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PIPE_TUNE1','m' ,91,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PIPE_TUNE1','m' ,91,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PIPE_TUNE1','m' ,173,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PIPE_TUNE1','m' ,173,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PIPE_TUNE1','m' ,139,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PIPE_TUNE1','m' ,91,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PIPE_TUNE1','m' ,55,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PIPE_TUNE1','m' ,70,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PIPE_TUNE1','m' ,40,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_TUNE1','m' ,77,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PIPE_TUNE1','m' ,77,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PIPE_TUNE1','m' ,83,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PIPE_TUNE1','m' ,-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PIPE_TUNE1','m' ,-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PIPE_TUNE1','m' ,-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PIPE_TUNE1','m' ,-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PIPE_TUNE1','m' ,-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PIPE_TUNE1','m' ,-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_TUNE_EXP_COEFF','unitless',1.6,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PIPE_TUNE_EXP_COEFF','unitless',1.6,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.33,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.47,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.47,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.05,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.33,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PIPE_TUNE_EXP_COEFF','unitless',0.85,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PIPE_TUNE_EXP_COEFF','unitless',0.85,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.16,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.16,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.7,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.7,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PIPE_TUNE_EXP_COEFF','unitless',1.16,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PIPE_TUNE_EXP_COEFF','unitless',1.3,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PIPE_TUNE_EXP_COEFF','unitless',1.49,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PIPE_TUNE_EXP_COEFF','unitless',1.11,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_TUNE_EXP_COEFF','unitless',1.21,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PIPE_TUNE_EXP_COEFF','unitless',1.21,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PIPE_TUNE_EXP_COEFF','unitless',1.4,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PIPE_TUNE2','m',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_TUNE2','m',40,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PIPE_TUNE2','m',40,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PIPE_TUNE2','m',32,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PIPE_TUNE2','m',33,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PIPE_TUNE2','m',29,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PIPE_TUNE2','m',35,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PIPE_TUNE2','m',32,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PIPE_TUNE2','m',14,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PIPE_TUNE2','m',14,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PIPE_TUNE2','m',35,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PIPE_TUNE2','m',35,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PIPE_TUNE2','m',32,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PIPE_TUNE2','m',32,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PIPE_TUNE2','m',39,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PIPE_TUNE2','m',35,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PIPE_TUNE2','m',43,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PIPE_TUNE2','m',41,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PIPE_TUNE2','m',45,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_TUNE2','m',41,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PIPE_TUNE2','m',41,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PIPE_TUNE2','m',30,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PIPE_TUNE2','m',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PIPE_TUNE2','m',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PIPE_TUNE2','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PIPE_TUNE2','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PIPE_TUNE2','m',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PIPE_TUNE2','m',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PIPE_TUNE3','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_TUNE3','unitless',0.65,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PIPE_TUNE3','unitless',0.65,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PIPE_TUNE3','unitless',0.57,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PIPE_TUNE3','unitless',0.63,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PIPE_TUNE3','unitless',0.53,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PIPE_TUNE3','unitless',0.54,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PIPE_TUNE3','unitless',0.57,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PIPE_TUNE3','unitless',0.33,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PIPE_TUNE3','unitless',0.33,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PIPE_TUNE3','unitless',0.66,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PIPE_TUNE3','unitless',0.66,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PIPE_TUNE3','unitless',0.52,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PIPE_TUNE3','unitless',0.52,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PIPE_TUNE3','unitless',0.5,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PIPE_TUNE3','unitless',0.66,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PIPE_TUNE3','unitless',0.58,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PIPE_TUNE3','unitless',0.59,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PIPE_TUNE3','unitless',0.57,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_TUNE3','unitless',0.66,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PIPE_TUNE3','unitless',0.66,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PIPE_TUNE3','unitless',0.52,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PIPE_TUNE3','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PIPE_TUNE3','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PIPE_TUNE3','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PIPE_TUNE3','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PIPE_TUNE3','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PIPE_TUNE3','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','K_LATOSA_MAX','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',3400,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',3400,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',1600,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LATOSA_MAX','unitless',495,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LATOSA_MAX','unitless',1745,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LATOSA_MAX','unitless',3250,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LATOSA_MAX','unitless',1600,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',3079,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LATOSA_MAX','unitless',3079,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',2800,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LATOSA_MAX','unitless',2800,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LATOSA_MAX','unitless',4430,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LATOSA_MAX','unitless',3100,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LATOSA_MAX','unitless',4500,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LATOSA_MAX','unitless',2800,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',2800,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LATOSA_MAX','unitless',2600,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LATOSA_MAX','unitless',3000,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',2500,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LATOSA_MAX','unitless',2500,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',6000,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',1.3,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',1.3,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',1,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MAX','unitless',2,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',0.1,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',0.1,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','K_LATOSA_MIN','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',3300,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',3300,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',417,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LATOSA_MIN','unitless',300,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LATOSA_MIN','unitless',250,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LATOSA_MIN','unitless',700,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LATOSA_MIN','unitless',417,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',675,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LATOSA_MIN','unitless',675,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',1800,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LATOSA_MIN','unitless',1800,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LATOSA_MIN','unitless',2700,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LATOSA_MIN','unitless',2020,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LATOSA_MIN','unitless',4300,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LATOSA_MIN','unitless',1800,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MIN','unitless',1600,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LATOSA_MIN','unitless',900,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LATOSA_MIN','unitless',2300,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',2400,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LATOSA_MIN','unitless',2400,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',5000,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',1.3,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',1.3,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',1,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MIN','unitless',2,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MIN','unitless',0.1,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',0.1,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','HEIGHT_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','HEIGHT_INIT_MIN','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','HEIGHT_INIT_MIN','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','HEIGHT_INIT_MIN','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','HEIGHT_INIT_MIN','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','HEIGHT_INIT_MIN','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','HEIGHT_INIT_MIN','m',3,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','HEIGHT_INIT_MIN','m',2,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','HEIGHT_INIT_MIN','m',4,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','HEIGHT_INIT_MIN','m',0.3,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','HEIGHT_INIT_MIN','m',0.3,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','HEIGHT_INIT_MIN','m',0.3,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','HEIGHT_INIT_MIN','m',0.1,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','HEIGHT_INIT_MIN','m',0.1,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','HEIGHT_INIT_MIN','m',0.1,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','HEIGHT_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','HEIGHT_INIT_MAX','m',15,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','HEIGHT_INIT_MAX','m',15,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','HEIGHT_INIT_MAX','m',4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','HEIGHT_INIT_MAX','m',4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','HEIGHT_INIT_MAX','m',4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','HEIGHT_INIT_MAX','m',4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','HEIGHT_INIT_MAX','m',4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','HEIGHT_INIT_MAX','m',4,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','HEIGHT_INIT_MAX','m',3,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','HEIGHT_INIT_MAX','m',5,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','HEIGHT_INIT_MAX','m',0.3,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','HEIGHT_INIT_MAX','m',0.3,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','HEIGHT_INIT_MAX','m',0.3,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','HEIGHT_INIT_MAX','m',0.1,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','HEIGHT_INIT_MAX','m',0.1,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','HEIGHT_INIT_MAX','m',0.1,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','DIA_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','DIA_INIT_MIN','m',0.02,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','DIA_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','DIA_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','DIA_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','DIA_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','DIA_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','DIA_INIT_MIN','m',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','DIA_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','DIA_INIT_MAX','m',0.13,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','DIA_INIT_MAX','m',0.13,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','DIA_INIT_MAX','m',0.03,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','DIA_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','DIA_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','DIA_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','DIA_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','DIA_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','DIA_INIT_MAX','m',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','NMAXTREES','ha-1',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','NMAXTREES','ha-1',2000,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','NMAXTREES','ha-1',2000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','NMAXTREES','ha-1',7333,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','NMAXTREES','ha-1',8000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','NMAXTREES','ha-1',6000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','NMAXTREES','ha-1',8000,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','NMAXTREES','ha-1',7333,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','NMAXTREES','ha-1',8000,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','NMAXTREES','ha-1',8000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','NMAXTREES','ha-1',8000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','NMAXTREES','ha-1',8000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','NMAXTREES','ha-1',8000,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','NMAXTREES','ha-1',15000,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','NMAXTREES','ha-1',10000,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','NMAXTREES','ha-1',10000,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','NMAXTREES','ha-1',10000,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','NMAXTREES','ha-1',10000,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','NMAXTREES','ha-1',10000,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','NMAXTREES','ha-1',10000,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','FRUIT_ALLOC','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','FRUIT_ALLOC','unitless',0.025,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','FRUIT_ALLOC','unitless',0.025,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','FRUIT_ALLOC','unitless',0.1,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','FRUIT_ALLOC','unitless',0.05,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','CN_LEAF_PRESCRIBED','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','CN_LEAF_PRESCRIBED','unitless',29,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','FCN_WOOD','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','FCN_WOOD','unitless',0.087,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','FCN_ROOT','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','FCN_ROOT','unitless',0.86,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','COEFF_MAINT_INIT','gC.gN.day-1',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.0338,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.0364,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.036,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.038,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0175,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0379,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.036,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0291,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0291,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0107,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0107,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0095,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0021,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0083,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.0097,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.038,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.0346,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.0467,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.0267,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.0267,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.066,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.01,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.01,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.01,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.025,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.025,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.025,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LAI_TOP','m2 m-2',1,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LAI_TOP','m2 m-2',0.2,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LAI_TOP','m2 m-2',0.1,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LAI_TOP','m2 m-2',5.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LAI_TOP','m2 m-2',5.0,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LAI_TOP','m2 m-2',5.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LAI_TOP','m2 m-2',5.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LAI_TOP','m2 m-2',5.0,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LAI_TOP','m2 m-2',5.0,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PSI_LEAF','MPa' ,-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PSI_LEAF','MPa' ,-1.95,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PSI_LEAF','MPa' ,-1.6,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PSI_LEAF','MPa' ,-2.3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PSI_LEAF','MPa' ,-1.95,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PSI_LEAF','MPa' ,-1.95,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PSI_LEAF','MPa' ,-4.48,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PSI_LEAF','MPa' ,-4.48,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PSI_LEAF','MPa' ,-0.94,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PSI_LEAF','MPa' ,-0.94,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PSI_LEAF','MPa' ,-2.15,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PSI_LEAF','MPa' ,-2.94,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PSI_LEAF','MPa' ,-1.62,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PSI_LEAF','MPa' ,-0.94,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PSI_LEAF','MPa' ,-1.78,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PSI_LEAF','MPa' ,-1.6,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PSI_LEAF','MPa' ,-1.95,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PSI_LEAF','MPa' ,-0.94,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PSI_LEAF','MPa' ,-0.94,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PSI_LEAF','MPa' ,-1.6,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PSI_LEAF','MPa' ,-2.2,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PSI_50','MPa' ,-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PSI_50','MPa' ,-3.0,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PSI_50','MPa' ,-3.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PSI_50','MPa' ,-3.52,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PSI_50','MPa' ,-3.36,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PSI_50','MPa' ,-3.22,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PSI_50','MPa' ,-3.98,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PSI_50','MPa' ,-3.52,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PSI_50','MPa' ,-3.83,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PSI_50','MPa' ,-3.83,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PSI_50','MPa' ,-2.4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PSI_50','MPa' ,-2.4,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PSI_50','MPa' ,-3.98,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PSI_50','MPa' ,-3.23,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PSI_50','MPa' ,-2.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PSI_50','MPa' ,-2.4,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PSI_50','MPa' ,-2.8,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PSI_50','MPa' ,-2.4,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PSI_50','MPa' ,-3.2,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PSI_50','MPa' ,-3.15,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PSI_50','MPa' ,-3.15,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PSI_50','MPa' ,-3.66,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PSI_50','MPa' ,-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PSI_50','MPa' ,-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PSI_50','MPa' ,-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PSI_50','MPa' ,-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PSI_50','MPa' ,-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PSI_50','MPa' ,-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','K_SAP','m2 s-1MPa',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_SAP','m2 s-1MPa',1.00E-03,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_SAP','m2 s-1MPa',1.00E-03,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_SAP','m2 s-1MPa',5.34E-04,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_SAP','m2 s-1MPa',8.50E-04,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_SAP','m2 s-1MPa',3.52E-04,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_SAP','m2 s-1MPa',4.00E-04,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','K_SAP','m2 s-1MPa',5.34E-04,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_SAP','m2 s-1MPa',1.08E-04,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_SAP','m2 s-1MPa',1.08E-04,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_SAP','m2 s-1MPa',3.00E-03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_SAP','m2 s-1MPa',3.00E-03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_SAP','m2 s-1MPa',3.60E-04,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_SAP','m2 s-1MPa',1.03E-03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_SAP','m2 s-1MPa',3.00E-03,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_SAP','m2 s-1MPa',3.00E-03,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_SAP','m2 s-1MPa',6.25E-04,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_SAP','m2 s-1MPa',8.50E-04,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_SAP','m2 s-1MPa',4.00E-04,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_SAP','m2 s-1MPa',3.00E-03,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_SAP','m2 s-1MPa',3.00E-03,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_SAP','m2 s-1MPa',5.82E-04,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','K_SAP','m2 s-1MPa',3.00E-04,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','K_SAP','m2 s-1MPa',3.00E-04,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','K_SAP','m2 s-1MPa',3.00E-04,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','K_SAP','m2 s-1MPa',3.00E-04,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','K_SAP','m2 s-1MPa',3.00E-04,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','K_SAP','m2 s-1MPa',3.00E-04,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','K_ROOT','m3 kg-1 s-1 MPa-1',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-06,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-06,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',3.30E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.30E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',3.30E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',4.29E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',3.30E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.56E-06,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.56E-06,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.51E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.51E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.01E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',3.02E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.51E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',2.51E-07,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',2.38E-07,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',2.30E-07,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',2.45E-07,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',2.51E-07,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',2.51E-07,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',3.00E-07,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-07,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-07,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-07,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-07,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-07,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-07,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','K_LEAF','m s-1 MPa-1',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LEAF','m s-1 MPa-1',2.50E-07,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LEAF','m s-1 MPa-1',2.50E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LEAF','m s-1 MPa-1',3.52E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LEAF','m s-1 MPa-1',3.52E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LEAF','m s-1 MPa-1',3.50E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LEAF','m s-1 MPa-1',3.51E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LEAF','m s-1 MPa-1',3.51E-07,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LEAF','m s-1 MPa-1',3.52E-07,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LEAF','m s-1 MPa-1',1.50E-07,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LEAF','m s-1 MPa-1',3.52E-07,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LEAF','m s-1 MPa-1',3.52E-07,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LEAF','m s-1 MPa-1',2.50E-07,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','K_LEAF','m s-1 MPa-1',3.00E-07,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','K_LEAF','m s-1 MPa-1',3.00E-07,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','K_LEAF','m s-1 MPa-1',3.00E-07,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','K_LEAF','m s-1 MPa-1',3.00E-07,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','K_LEAF','m s-1 MPa-1',3.00E-07,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','K_LEAF','m s-1 MPa-1',3.00E-07,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','PSI_SOIL_TUNE','MPa',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PSI_SOIL_TUNE','MPa',0.67,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PSI_SOIL_TUNE','MPa',0.5,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PSI_SOIL_TUNE','MPa',0.5,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PSI_SOIL_TUNE','MPa',1.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PSI_SOIL_TUNE','MPa',0.67,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PSI_SOIL_TUNE','MPa',2.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PSI_SOIL_TUNE','MPa',2.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PSI_SOIL_TUNE','MPa',4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PSI_SOIL_TUNE','MPa',4.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PSI_SOIL_TUNE','MPa',6.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PSI_SOIL_TUNE','MPa',2.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PSI_SOIL_TUNE','MPa',3.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PSI_SOIL_TUNE','MPa',3.0,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PSI_SOIL_TUNE','MPa',0.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','PSI_SOIL_TUNE','MPa',3.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','PSI_SOIL_TUNE','MPa',3.0,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','PSI_SOIL_TUNE','MPa',0.75,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PSI_SOIL_TUNE','MPa',4.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PSI_SOIL_TUNE','MPa',4.0,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PSI_SOIL_TUNE','MPa',0.75,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','ALPHA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_SELF_THINNING','unitless',700,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALPHA_SELF_THINNING','unitless',700,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',1456,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_SELF_THINNING','unitless',1236,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_SELF_THINNING','unitless',1626,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_SELF_THINNING','unitless',1507,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','ALPHA_SELF_THINNING','unitless',1456,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',1678,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_SELF_THINNING','unitless',1678,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_SELF_THINNING','unitless',1272,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_SELF_THINNING','unitless',1644,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_SELF_THINNING','unitless',1965,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_SELF_THINNING','unitless',1532,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_SELF_THINNING','unitless',1407,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALPHA_SELF_THINNING','unitless',1644,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_SELF_THINNING','unitless',1272,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_SELF_THINNING','unitless',991,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_SELF_THINNING','unitless',1166,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_SELF_THINNING','unitless',1344,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_SELF_THINNING','unitless',1344,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_SELF_THINNING','unitless',1426,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','ALPHA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','ALPHA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','ALPHA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','ALPHA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','ALPHA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','ALPHA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','BETA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BETA_SELF_THINNING','unitless',-0.5,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BETA_SELF_THINNING','unitless',-0.5,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.58,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_SELF_THINNING','unitless',-0.57,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_SELF_THINNING','unitless',-0.59,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_SELF_THINNING','unitless',-0.59,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','BETA_SELF_THINNING','unitless',-0.58,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.64,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BETA_SELF_THINNING','unitless',-0.64,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_SELF_THINNING','unitless',-0.61,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_SELF_THINNING','unitless',-0.61,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_SELF_THINNING','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_SELF_THINNING','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_SELF_THINNING','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','BETA_SELF_THINNING','unitless',-0.61,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_SELF_THINNING','unitless',-0.58,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_SELF_THINNING','unitless',-0.58,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_SELF_THINNING','unitless',-0.58,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_SELF_THINNING','unitless',-0.6,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_SELF_THINNING','unitless',-0.6,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_SELF_THINNING','unitless',-0.6,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','BETA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','BETA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','BETA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','BETA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','BETA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','BETA_SELF_THINNING','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','H_FIRST','m',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','H_FIRST','m',15,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','H_FIRST','m',15,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','H_FIRST','m',6,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','H_FIRST','m',6,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','H_FIRST','m',6,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','H_FIRST','m',6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','H_FIRST','m',8,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','H_FIRST','m',8,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','H_FIRST','m',8,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','H_FIRST','m',8,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','H_FIRST','m',8,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','H_FIRST','m',8,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','H_FIRST','m',8,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','H_FIRST','m',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','H_FIRST','m',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','H_FIRST','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','H_FIRST','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','H_FIRST','m',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','H_FIRST','m',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','ALPHA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_RDI_UPPER','unitless',1180,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALPHA_RDI_UPPER','unitless',1180,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_RDI_UPPER','unitless',1330,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_RDI_UPPER','unitless',976,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_RDI_UPPER','unitless',1556,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_RDI_UPPER','unitless',1457,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','ALPHA_RDI_UPPER','unitless',1330,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_RDI_UPPER','unitless',2020,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_RDI_UPPER','unitless',2020,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_RDI_UPPER','unitless',1640,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_RDI_UPPER','unitless',1640,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_RDI_UPPER','unitless',1960,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_RDI_UPPER','unitless',1530,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_RDI_UPPER','unitless',1437,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALPHA_RDI_UPPER','unitless',1640,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_RDI_UPPER','unitless',889,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_RDI_UPPER','unitless',801,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_RDI_UPPER','unitless',976,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_RDI_UPPER','unitless',1640,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_RDI_UPPER','unitless',1640,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_RDI_UPPER','unitless',1456,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','ALPHA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','ALPHA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','BETA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BETA_RDI_UPPER','unitless',-0.57,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BETA_RDI_UPPER','unitless',-0.57,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_RDI_UPPER','unitless',-0.58,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_RDI_UPPER','unitless',-0.57,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_RDI_UPPER','unitless',-0.59,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_RDI_UPPER','unitless',-0.59,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','BETA_RDI_UPPER','unitless',-0.58,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_RDI_UPPER','unitless',-0.64,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BETA_RDI_UPPER','unitless',-0.64,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_RDI_UPPER','unitless',-0.61,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_RDI_UPPER','unitless',-0.61,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_RDI_UPPER','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_RDI_UPPER','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_RDI_UPPER','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','BETA_RDI_UPPER','unitless',-0.61,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_RDI_UPPER','unitless',-0.58,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_RDI_UPPER','unitless',-0.58,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_RDI_UPPER','unitless',-0.58,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_RDI_UPPER','unitless',-0.6,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_RDI_UPPER','unitless',-0.6,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_RDI_UPPER','unitless',-0.6,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','BETA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','BETA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','BETA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','BETA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','BETA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','BETA_RDI_UPPER','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','ALPHA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_RDI_LOWER','unitless',1100,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALPHA_RDI_LOWER','unitless',1100,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_RDI_LOWER','unitless',1820,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_RDI_LOWER','unitless',776,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_RDI_LOWER','unitless',1426,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_RDI_LOWER','unitless',1327,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','ALPHA_RDI_LOWER','unitless',1820,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_RDI_LOWER','unitless',1500,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_RDI_LOWER','unitless',1500,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_RDI_LOWER','unitless',1500,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_RDI_LOWER','unitless',1500,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_RDI_LOWER','unitless',1700,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_RDI_LOWER','unitless',1300,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_RDI_LOWER','unitless',1267,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALPHA_RDI_LOWER','unitless',1500,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_RDI_LOWER','unitless',719,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_RDI_LOWER','unitless',631,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_RDI_LOWER','unitless',806,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_RDI_LOWER','unitless',1500,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_RDI_LOWER','unitless',1500,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_RDI_LOWER','unitless',1286,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','ALPHA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','ALPHA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','BETA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BETA_RDI_LOWER','unitless',-0.57,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BETA_RDI_LOWER','unitless',-0.57,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_RDI_LOWER','unitless',-0.58,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_RDI_LOWER','unitless',-0.57,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_RDI_LOWER','unitless',-0.59,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_RDI_LOWER','unitless',-0.59,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','BETA_RDI_LOWER','unitless',-0.58,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_RDI_LOWER','unitless',-0.64,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BETA_RDI_LOWER','unitless',-0.64,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_RDI_LOWER','unitless',-0.61,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_RDI_LOWER','unitless',-0.61,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_RDI_LOWER','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_RDI_LOWER','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_RDI_LOWER','unitless',-0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','BETA_RDI_LOWER','unitless',-0.61,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_RDI_LOWER','unitless',-0.58,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_RDI_LOWER','unitless',-0.58,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_RDI_LOWER','unitless',-0.58,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_RDI_LOWER','unitless',-0.6,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_RDI_LOWER','unitless',-0.6,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_RDI_LOWER','unitless',-0.6,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','BETA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','BETA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','BETA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','BETA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','BETA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','BETA_RDI_LOWER','unitless',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LARGEST_TREE_DIA','m',-9999,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LARGEST_TREE_DIA','m',0.5,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LARGEST_TREE_DIA','m',0.5,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LARGEST_TREE_DIA','m',0.41,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LARGEST_TREE_DIA','m',0.41,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LARGEST_TREE_DIA','m',0.45,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LARGEST_TREE_DIA','m',0.4,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LARGEST_TREE_DIA','m',0.42,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LARGEST_TREE_DIA','m',0.35,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LARGEST_TREE_DIA','m',0.35,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LARGEST_TREE_DIA','m',0.45,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LARGEST_TREE_DIA','m',0.45,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LARGEST_TREE_DIA','m',0.6,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LARGEST_TREE_DIA','m',0.5,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LARGEST_TREE_DIA','m',0.5,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LARGEST_TREE_DIA','m',0.35,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LARGEST_TREE_DIA','m',0.45,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LARGEST_TREE_DIA','m',0.45,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LARGEST_TREE_DIA','m',0.45,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LARGEST_TREE_DIA','m',0.3,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LARGEST_TREE_DIA','m',0.3,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LARGEST_TREE_DIA','m',0.3,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LARGEST_TREE_DIA','m',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LARGEST_TREE_DIA','m',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LARGEST_TREE_DIA','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LARGEST_TREE_DIA','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LARGEST_TREE_DIA','m',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LARGEST_TREE_DIA','m',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LEAF_SSA_VIS','unitless',0.17291,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LEAF_SSA_VIS','unitless',0.12156,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LEAF_SSA_VIS','unitless',0.17413,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LEAF_SSA_VIS','unitless',0.13349,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LEAF_SSA_VIS','unitless',0.1529,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LEAF_SSA_VIS','unitless',0.1703,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LEAF_SSA_VIS','unitless',0.1504,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LEAF_SSA_VIS','unitless',0.1579,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LEAF_SSA_VIS','unitless',0.1343,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LEAF_SSA_VIS','unitless',0.1343,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LEAF_SSA_VIS','unitless',0.17218,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LEAF_SSA_VIS','unitless',0.1722,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LEAF_SSA_VIS','unitless',0.1415,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LEAF_SSA_VIS','unitless',0.1562,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LEAF_SSA_VIS','unitless',0.1395,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LEAF_SSA_VIS','unitless',0.1722,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_SSA_VIS','unitless',0.14711,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LEAF_SSA_VIS','unitless',0.1529,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LEAF_SSA_VIS','unitless',0.1504,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAF_SSA_VIS','unitless',0.14399,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LEAF_SSA_VIS','unitless',0.1722,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAF_SSA_VIS','unitless',0.15125,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LEAF_SSA_VIS','unitless',0.17455,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LEAF_SSA_VIS','unitless',0.17455,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LEAF_SSA_VIS','unitless',0.16981,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LEAF_SSA_VIS','unitless',0.17301,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LEAF_SSA_VIS','unitless',0.17301,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LEAF_SSA_VIS','unitless',0.17176,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LEAF_SSA_NIR','unitless',0.70275,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LEAF_SSA_NIR','unitless',0.67834,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LEAF_SSA_NIR','unitless',0.70136,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LEAF_SSA_NIR','unitless',0.68984,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LEAF_SSA_NIR','unitless',0.74131,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LEAF_SSA_NIR','unitless',0.78242,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LEAF_SSA_NIR','unitless',0.74644,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LEAF_SSA_NIR','unitless',0.7567,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LEAF_SSA_NIR','unitless',0.7341,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LEAF_SSA_NIR','unitless',0.73407,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LEAF_SSA_NIR','unitless',0.72176,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LEAF_SSA_NIR','unitless',0.72176,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LEAF_SSA_NIR','unitless',0.76699,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LEAF_SSA_NIR','unitless',0.74554,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LEAF_SSA_NIR','unitless',0.72523,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LEAF_SSA_NIR','unitless',0.72,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_SSA_NIR','unitless',0.69501,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LEAF_SSA_NIR','unitless',0.74131,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LEAF_SSA_NIR','unitless',0.74644,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAF_SSA_NIR','unitless',0.69201,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LEAF_SSA_NIR','unitless',0.72176,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAF_SSA_NIR','unitless',0.8498,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LEAF_SSA_NIR','unitless',0.71212,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LEAF_SSA_NIR','unitless',0.71212,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LEAF_SSA_NIR','unitless',0.71501,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LEAF_SSA_NIR','unitless',0.71259,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LEAF_SSA_NIR','unitless',0.71259,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LEAF_SSA_NIR','unitless',0.71295,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LEAF_PSD_VIS','unitless',1.003,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LEAF_PSD_VIS','unitless',0.965,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LEAF_PSD_VIS','unitless',1.001,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LEAF_PSD_VIS','unitless',0.969,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LEAF_PSD_VIS','unitless',1.040,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LEAF_PSD_VIS','unitless',1.095,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LEAF_PSD_VIS','unitless',1.040,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LEAF_PSD_VIS','unitless',1.058,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LEAF_PSD_VIS','unitless',1.026,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LEAF_PSD_VIS','unitless',1.026,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LEAF_PSD_VIS','unitless',1.036,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LEAF_PSD_VIS','unitless',1.036,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LEAF_PSD_VIS','unitless',1.071,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LEAF_PSD_VIS','unitless',1.043,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LEAF_PSD_VIS','unitless',1.021,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LEAF_PSD_VIS','unitless',1.040,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_PSD_VIS','unitless',0.978,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LEAF_PSD_VIS','unitless',1.040,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LEAF_PSD_VIS','unitless',1.040,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAF_PSD_VIS','unitless',0.978,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LEAF_PSD_VIS','unitless',1.036,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAF_PSD_VIS','unitless',1.175,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LEAF_PSD_VIS','unitless',1.004,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LEAF_PSD_VIS','unitless',1.004,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LEAF_PSD_VIS','unitless',1.000,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LEAF_PSD_VIS','unitless',1.003,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LEAF_PSD_VIS','unitless',1.003,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LEAF_PSD_VIS','unitless',1.002,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LEAF_PSD_NIR','unitless',2.006,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LEAF_PSD_NIR','unitless',1.943,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LEAF_PSD_NIR','unitless',2.003,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LEAF_PSD_NIR','unitless',1.975,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LEAF_PSD_NIR','unitless',2.116,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LEAF_PSD_NIR','unitless',2.234,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LEAF_PSD_NIR','unitless',2.135,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LEAF_PSD_NIR','unitless',2.162,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LEAF_PSD_NIR','unitless',2.095,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LEAF_PSD_NIR','unitless',2.095,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LEAF_PSD_NIR','unitless',2.058,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LEAF_PSD_NIR','unitless',2.058,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LEAF_PSD_NIR','unitless',2.196,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LEAF_PSD_NIR','unitless',2.116,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LEAF_PSD_NIR','unitless',2.073,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LEAF_PSD_NIR','unitless',2.060,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_PSD_NIR','unitless',1.988,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LEAF_PSD_NIR','unitless',2.116,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LEAF_PSD_NIR','unitless',2.135,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAF_PSD_NIR','unitless',1.974,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LEAF_PSD_NIR','unitless',2.058,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAF_PSD_NIR','unitless',2.435,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LEAF_PSD_NIR','unitless',2.024,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LEAF_PSD_NIR','unitless',2.024,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LEAF_PSD_NIR','unitless',2.024,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LEAF_PSD_NIR','unitless',2.021,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LEAF_PSD_NIR','unitless',2.021,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LEAF_PSD_NIR','unitless',2.024,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','BGRD_REF_VIS','unitless',0.13128,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BGRD_REF_VIS','unitless',0.08002,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BGRD_REF_VIS','unitless',0.10057,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BGRD_REF_VIS','unitless',0.05125,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BGRD_REF_VIS','unitless',0.056095,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BGRD_REF_VIS','unitless',0.058601,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BGRD_REF_VIS','unitless',0.042981,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','BGRD_REF_VIS','unitless',0.0526,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BGRD_REF_VIS','unitless',0.0559,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BGRD_REF_VIS','unitless',0.0559,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BGRD_REF_VIS','unitless',0.08873,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BGRD_REF_VIS','unitless',0.088728,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BGRD_REF_VIS','unitless',0.051854,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BGRD_REF_VIS','unitless',0.10024,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BGRD_REF_VIS','unitless',0.057965,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','BGRD_REF_VIS','unitless',0.09,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BGRD_REF_VIS','unitless',0.03511,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BGRD_REF_VIS','unitless',0.056095,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BGRD_REF_VIS','unitless',0.042981,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BGRD_REF_VIS','unitless',0.0597,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BGRD_REF_VIS','unitless',0.088728,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','BGRD_REF_VIS','unitless',0.05174,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','BGRD_REF_VIS','unitless',0.13085,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','BGRD_REF_VIS','unitless',0.13085,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','BGRD_REF_VIS','unitless',0.1177,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','BGRD_REF_VIS','unitless',0.11008,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','BGRD_REF_VIS','unitless',0.11008,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','BGRD_REF_VIS','unitless',0.124,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','BGRD_REF_NIR','unitless',0.24556,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BGRD_REF_NIR','unitless',0.13978,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BGRD_REF_NIR','unitless',0.17651,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BGRD_REF_NIR','unitless',0.08851,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BGRD_REF_NIR','unitless',0.093891,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BGRD_REF_NIR','unitless',0.098511,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BGRD_REF_NIR','unitless',0.073559,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','BGRD_REF_NIR','unitless',0.0887,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BGRD_REF_NIR','unitless',0.0957,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BGRD_REF_NIR','unitless',0.095732,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BGRD_REF_NIR','unitless',0.14427,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BGRD_REF_NIR','unitless',0.14427,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BGRD_REF_NIR','unitless',0.089514,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BGRD_REF_NIR','unitless',0.17743,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BGRD_REF_NIR','unitless',0.093873,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','BGRD_REF_NIR','unitless',0.14,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BGRD_REF_NIR','unitless',0.04983,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BGRD_REF_NIR','unitless',0.093891,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BGRD_REF_NIR','unitless',0.073559,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BGRD_REF_NIR','unitless',0.09275,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BGRD_REF_NIR','unitless',0.14427,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','BGRD_REF_NIR','unitless',0.08372,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','BGRD_REF_NIR','unitless',0.24711,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','BGRD_REF_NIR','unitless',0.24711,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','BGRD_REF_NIR','unitless',0.22773,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','BGRD_REF_NIR','unitless',0.20472,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','BGRD_REF_NIR','unitless',0.20472,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','BGRD_REF_NIR','unitless',0.23701,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','FUELWOOD_DIAMETER','m',-9999.0,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','FUELWOOD_DIAMETER','m',0.3,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','FUELWOOD_DIAMETER','m',0.3,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','FUELWOOD_DIAMETER','m',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','FUELWOOD_DIAMETER','m',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','FUELWOOD_DIAMETER','m',0.3,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','FUELWOOD_DIAMETER','m',0.2,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','FUELWOOD_DIAMETER','m',0.1,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','FUELWOOD_DIAMETER','m',0.1,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','FUELWOOD_DIAMETER','m',0.1,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','FUELWOOD_DIAMETER','m',-9999,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','FUELWOOD_DIAMETER','m',-9999,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','FUELWOOD_DIAMETER','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','FUELWOOD_DIAMETER','m',-9999,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','FUELWOOD_DIAMETER','m',-9999,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','FUELWOOD_DIAMETER','m',-9999,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALLOC_MIN','unitless',0.7,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALLOC_MIN','unitless',0.75,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALLOC_MIN','unitless',0.75,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALLOC_MIN','unitless',0.85,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALLOC_MIN','unitless',0.35,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALLOC_MIN','unitless',0.5,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALLOC_MIN','unitless',0.7,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALLOC_MIN','unitless',0.7,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','ALLOC_MIN','unitless',0.2,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALLOC_MAX','unitless',0.9,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','ALLOC_MAX','unitless',0.8,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','FRAC_GROWTHRESP','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','FRAC_GROWTHRESP','unitless',0.28,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','SENESCENSE_RESERVE','unitless',-9999.0,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','SENESCENSE_RESERVE','unitless',0.25,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','SENESCENSE_RESERVE','unitless',0.15,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','LABILE_RESERVE','unitless',0,'r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LABILE_RESERVE','unitless',60.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','LABILE_RESERVE','unitless',30.0,'r2566',''],
             [20150303,'BareSoil','SoilBare','Global','SRL','m g-1',-9999.00,'r4916',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','SRL','m g-1',10.0,'r4916',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','SRL','m g-1',10.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','SRL','m g-1',9.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','SRL','m g-1',9.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','SRL','m g-1',9.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','SRL','m g-1',12.5,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','SRL','m g-1',5.5,'r4916',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','SRL','m g-1',9.0,'r4916',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','SRL','m g-1',9.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SRL','m g-1',14.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','SRL','m g-1',14.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','SRL','m g-1',13.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','SRL','m g-1',15.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','SRL','m g-1',14.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','SRL','m g-1',14.0,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','SRL','m g-1',18.3,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','SRL','m g-1',18.3,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','SRL','m g-1',18.3,'r4916',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','SRL','m g-1',18.3,'r4916',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','SRL','m g-1',18.3,'r4916',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','SRL','m g-1',18.3,'r4916',''],
             [20150303,'C3Grass','C3Grass','Boreal','SRL','m g-1',18.0,'r4916',''],
             [20150303,'C3Grass','C3Grass','Temperate','SRL','m g-1',18.0,'r4916',''],
             [20150303,'C4Grass','C4Grass','Temperate','SRL','m g-1',18.0,'r4916',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','SRL','m g-1',18.0,'r4916',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','SRL','m g-1',18.0,'r4916',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','SRL','m g-1',18.0,'r4916',''],
             [20150303,'BareSoil','SoilBare','Global','R_FROOT','m',-9999.00,'r4916',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','R_FROOT','m',2.90E-04,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','R_FROOT','m',2.40E-04,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','R_FROOT','m',2.40E-04,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','R_FROOT','m',2.40E-04,'r4916',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','R_FROOT','m',2.10E-04,'r4916',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','R_FROOT','m',2.10E-04,'r4916',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','R_FROOT','m',2.10E-04,'r4916',''],
             [20150303,'C3Grass','C3Grass','Boreal','R_FROOT','m',7.50E-05,'r4916',''],
             [20150303,'C3Grass','C3Grass','Temperate','R_FROOT','m',7.50E-05,'r4916',''],
             [20150303,'C4Grass','C4Grass','Temperate','R_FROOT','m',7.50E-05,'r4916',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','R_FROOT','m',1.68E-04,'r4916',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','R_FROOT','m',1.68E-04,'r4916',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','R_FROOT','m',1.68E-04,'r4916',''],
             [20150303,'BareSoil','SoilBare','Global','PSI_ROOT','MPa',-9999.00,'r4916',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PSI_ROOT','MPa',-3.0,'r4916',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'C3Grass','C3Grass','Boreal','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'C3Grass','C3Grass','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'C4Grass','C4Grass','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','PSI_ROOT','MPa',-4.0,'r4916',''],
             [20150303,'BareSoil','SoilBare','Global','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','RECRUITMENT_PFT','y/n','TRUE','r2566',''],
             [20150303,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','RECRUITMENT_PFT','y/n','TRUE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateNeedleleafEvergreen','Residual','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafEvergreen','PiceaSp','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'BorealNeedleleafSummergreen','LarixSp','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'C3Grass','C3Grass','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'C3Grass','C3Grass','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'C4Grass','C4Grass','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Boreal','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'C3Agriculture','C3Agriculture','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'C4Agriculture','C4Agriculture','Temperate','RECRUITMENT_PFT','y/n','FALSE','r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COPPICE_DIAMETER','m',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','COPPICE_DIAMETER','m',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','COPPICE_DIAMETER','m',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','COPPICE_DIAMETER','m',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','COPPICE_DIAMETER','m',0.1,'r2566',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','COPPICE_DIAMETER','m',0.1,'r2566',''],
             [20190315,'BareSoil','SoilBare','Global','K_LATOSA_MAX','unitless',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',3300,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',3300,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',417,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LATOSA_MAX','unitless',300,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LATOSA_MAX','unitless',250,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LATOSA_MAX','unitless',700,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LATOSA_MAX','unitless',417,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',675,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LATOSA_MAX','unitless',675,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',1800,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LATOSA_MAX','unitless',1800,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LATOSA_MAX','unitless',2700,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LATOSA_MAX','unitless',2020,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LATOSA_MAX','unitless',4300,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LATOSA_MAX','unitless',1800,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',1600,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LATOSA_MAX','unitless',900,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LATOSA_MAX','unitless',2300,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',2400,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LATOSA_MAX','unitless',2400,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',5000,'r5800',''],
             [20190315,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',1.3,'r5800',''],
             [20190315,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',1.3,'r5800',''],
             [20190315,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',1,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MAX','unitless',2,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',0.1,'r5800',''],
             [20190315,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',0.1,'r5800',''],
             [20190315,'BareSoil','SoilBare','Global','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_RDI_UPPER','unitless',0.16,'r5800',''],
             [20190315,'C3Grass','C3Grass','Boreal','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C4Grass','C4Grass','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Boreal','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C4Agriculture','C4Agriculture','Temperate','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'BareSoil','SoilBare','Global','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_RDI_UPPER','unitless',0.0255,'r5800',''],
             [20190315,'C3Grass','C3Grass','Boreal','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Temperate','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C4Grass','C4Grass','Temperate','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Boreal','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Temperate','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C4Agriculture','C4Agriculture','Temperate','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'BareSoil','SoilBare','Global','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_RDI_LOWER','unitless',0.051,'r5800',''],
             [20190315,'C3Grass','C3Grass','Boreal','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C4Grass','C4Grass','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Boreal','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C4Agriculture','C4Agriculture','Temperate','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'BareSoil','SoilBare','Global','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_RDI_LOWER','unitless',0.0264,'r5800',''],
             [20190315,'C3Grass','C3Grass','Boreal','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Temperate','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C4Grass','C4Grass','Temperate','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Boreal','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Temperate','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C4Agriculture','C4Agriculture','Temperate','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'BareSoil','SoilBare','Global','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','DIA_INIT_MIN','m',0.02,'r5800',''],
             [20190315,'C3Grass','C3Grass','Boreal','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Temperate','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'C4Grass','C4Grass','Temperate','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Boreal','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Temperate','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'C4Agriculture','C4Agriculture','Temperate','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'BareSoil','SoilBare','Global','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','DIA_INIT_MAX','m',0.13,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','DIA_INIT_MAX','m',0.13,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','DIA_INIT_MAX','m',0.03,'r5800',''],
             [20190315,'C3Grass','C3Grass','Boreal','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Temperate','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'C4Grass','C4Grass','Temperate','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Boreal','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'C3Agriculture','C3Agriculture','Temperate','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'C4Agriculture','C4Agriculture','Temperate','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Boreal','VCMAX25','umol m-2s-1',50,'r5800',''],
             [20190316,'C3Grass','C3Grass','Temperate','VCMAX25','umol m-2s-1',50,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','IS_TEMPERATE','y/n','FALSE','r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','IS_BOREAL','y/n','FALSE','r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','VCMAX25','umol m-2s-1',50,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','ARJV','unitless',2.0,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','ALPHA_LL','mol e- (mol photon)-1',0.3,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','TPHOTO_MIN_C','degrees C',-3.25,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','SLA','m2 gC-1',0.026,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','TAU_ROOT','days',310,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','TAU_LEAF','days',200,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','TAU_SAP','days',730,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','GPP_TO_LABILE','unitless',1,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','HYDROL_HUMCSTE','unitless',4.0,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PHENO_MODEL','unitless','none','r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PHENO_TYPE','unitless',1,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','SENESCENCE_TYPE','unitless','none','r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','SENESCENCE_TEMP_C','degrees C',9.38,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','HARVEST_RATIO','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LEAFFALL','days',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LEAFAGECRIT','days',120,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','RESIDENCE_TIME','years',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','DEATH_DF','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PIPE_DENSITY','gC m-3',200000,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','TREE_FF','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PIPE_TUNE1','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PIPE_TUNE_EXP_COEFF','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PIPE_TUNE2','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PIPE_TUNE3','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',1.3,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',1.3,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','HEIGHT_INIT_MIN','m',0.3,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','HEIGHT_INIT_MAX','m',0.3,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','NMAXTREES','ha-1',10000,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','FRUIT_ALLOC','unitless',0.05,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','CN_LEAF_PRESCRIBED','unitless',29,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','FCN_WOOD','unitless',0.087,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','FCN_ROOT','unitless',0.86,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.01,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LAI_TOP','m2 m-2',5.0,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PSI_LEAF','MPa',-2.2,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PSI_50','MPa',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','K_SAP','m2 s-1MPa',3.00E-04,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','K_ROOT','m3 kg-1 s-1 MPa-1',1.00E-07,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','K_LEAF','m s-1 MPa-1',3.00E-07,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','ALPHA_SELF_THINNING','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','BETA_SELF_THINNING','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','H_FIRST','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LARGEST_TREE_DIA','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LEAF_SSA_VIS','unitless',0.17455,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LEAF_SSA_NIR','unitless',0.71212,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LEAF_PSD_VIS','unitless',1.004,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LEAF_PSD_NIR','unitless',2.024,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','BGRD_REF_VIS','unitless',0.13085,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','BGRD_REF_NIR','unitless',0.24711,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','FUELWOOD_DIAMETER','m',-9999,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','ALLOC_MIN','unitless',0.2,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','ALLOC_MAX','unitless',0.8,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','FRAC_GROWTHRESP','unitless',0.28,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','SENESCENSE_RESERVE','unitless',0.15,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','LABILE_RESERVE','unitless',30.0,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','SRL','m g-1',18.0,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','R_FROOT','m',7.50E-05,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','PSI_ROOT','MPa',-4.0,'r5800',''],
             [20190316,'C3Grass','C3Grass','Tropical','RECRUITMENT_PFT','y/n','FALSE','r5800',''],
             [20190315,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',1.3,'r5800',''],
             [20190315,'C3Grass','C3Grass','Tropical','ALPHA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Tropical','BETA_RDI_UPPER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Tropical','ALPHA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Tropical','BETA_RDI_LOWER','unitless',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Tropical','DIA_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'C3Grass','C3Grass','Tropical','DIA_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','HEIGHT_INIT_MIN','m',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','HEIGHT_INIT_MAX','m',-9999,'r5800',''],
             [20190315,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateNeedleleafEvergreen','Residual','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'TemperateBroadLeavedSummergreen','Residual','Temperate','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'BorealNeedleleafEvergreen','PiceaSp','Boreal','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','NMAXTREES','ha-1',14000,'r5800',''],
             [20190315,'BorealNeedleleafSummergreen','LarixSp','Boreal','NMAXTREES','ha-1',14000,'r5800',''],
             [20150303,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_LL','mol e- (mol photon)-1',0.3,'r5800',''],
             [20190320,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','HYDROL_HUMCSTE','unitless',1.0,'r5800',''],
             [20190320,'BorealNeedleleafSummergreen','LarixSp','Boreal','HYDROL_HUMCSTE','unitless',1.0,'r5800',''],
             [20190320,'C3Grass','C3Grass','Boreal','HYDROL_HUMCSTE','unitless',0.6,'r5800',''],
             [20190320,'C3Grass','C3Grass','Temperate','HYDROL_HUMCSTE','unitless',0.6,'r5800',''],
             [20190320,'C4Grass','C4Grass','Temperate','HYDROL_HUMCSTE','unitless',0.6,'r5800',''],
             [20190320,'C3Agriculture','C3Agriculture','Boreal','HYDROL_HUMCSTE','unitless',0.6,'r5800',''],
             [20190320,'C3Agriculture','C3Agriculture','Temperate','HYDROL_HUMCSTE','unitless',0.6,'r5800',''],
             [20190320,'C4Agriculture','C4Agriculture','Temperate','HYDROL_HUMCSTE','unitless',0.6,'r5800',''],
             [20190320,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TREE_FF','unitless',0.6,'r5800',''],
             [20190320,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TREE_FF','unitless',0.6,'r5800',''],
             [20190320,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TREE_FF','unitless',0.6,'r5800',''],
             [20190320,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','TREE_FF','unitless',0.7,'r5800',''],
             [20190320,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TREE_FF','unitless',0.7,'r5800',''],
             [20190320,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','TREE_FF','unitless',0.7,'r5800',''],
             [20190320,'BorealNeedleleafEvergreen','PiceaSp','Boreal','TREE_FF','unitless',0.7,'r5800',''],
             [20190320,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','TREE_FF','unitless',0.6,'r5800',''],
             [20190320,'BorealNeedleleafSummergreen','LarixSp','Boreal','TREE_FF','unitless',0.6,'r5800',''],
             [20190320,'C3Grass','C3Grass','Tropical','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'TemperateBroadLeavedSummergreen','Residual','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'BorealNeedleleafSummergreen','LarixSp','Boreal','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'C3Grass','C3Grass','Boreal','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'C3Grass','C3Grass','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'C4Grass','C4Grass','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'C3Agriculture','C3Agriculture','Boreal','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'C3Agriculture','C3Agriculture','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190320,'C4Agriculture','C4Agriculture','Temperate','FRUIT_ALLOC','unitless',0.1,'r5800',''],
             [20190402,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',1110,'r5858',''],
             [20190402,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_SELF_THINNING','unitless',560,'r5858',''],
             [20190402,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_SELF_THINNING','unitless',355,'r5858',''],
             [20190402,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_SELF_THINNING','unitless',700,'r5858',''],
             [20190402,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',716,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_SELF_THINNING','unitless',4920,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_SELF_THINNING','unitless',1210,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_SELF_THINNING','unitless',585,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_SELF_THINNING','unitless',1620,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_SELF_THINNING','unitless',7860,'r5858',''],
             [20190402,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_SELF_THINNING','unitless',900,'r5858',''],
             [20190402,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.56,'r5858',''],
             [20190402,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_SELF_THINNING','unitless',-0.44,'r5858',''],
             [20190402,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_SELF_THINNING','unitless',-0.37,'r5858',''],
             [20190402,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_SELF_THINNING','unitless',-0.46,'r5858',''],
             [20190402,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.52,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_SELF_THINNING','unitless',-0.79,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_SELF_THINNING','unitless',-0.58,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_SELF_THINNING','unitless',-0.43,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_SELF_THINNING','unitless',-0.62,'r5858',''],
             [20190402,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_SELF_THINNING','unitless',-0.87,'r5858',''],
             [20190402,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_SELF_THINNING','unitless',-0.56,'r5858',''],
             [20190405,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',3400,'r5838',''],
             [20190405,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',3400,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',1900,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LATOSA_MAX','unitless',2500,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LATOSA_MAX','unitless',1200,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LATOSA_MAX','unitless',2000,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LATOSA_MAX','unitless',1900,'r5838',''],
             [20190405,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',2200,'r5838',''],
             [20190405,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LATOSA_MAX','unitless',2200,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',3900,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LATOSA_MAX','unitless',3500,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LATOSA_MAX','unitless',4430,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LATOSA_MAX','unitless',3100,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LATOSA_MAX','unitless',4500,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LATOSA_MAX','unitless',3900,'r5838',''],
             [20190405,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',2000,'r5838',''],
             [20190405,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LATOSA_MAX','unitless',2000,'r5838',''],
             [20190405,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LATOSA_MAX','unitless',2000,'r5838',''],
             [20190405,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',3500,'r5838',''],
             [20190405,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LATOSA_MAX','unitless',3500,'r5838',''],
             [20190405,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',5000,'r5838',''],
             [20190405,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',3400,'r5838',''],
             [20190405,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',3400,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',1900,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LATOSA_MIN','unitless',2500,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LATOSA_MIN','unitless',1200,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LATOSA_MIN','unitless',2000,'r5838',''],
             [20190405,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LATOSA_MIN','unitless',1900,'r5838',''],
             [20190405,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',2200,'r5838',''],
             [20190405,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LATOSA_MIN','unitless',2200,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',3900,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LATOSA_MIN','unitless',3500,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LATOSA_MIN','unitless',4430,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LATOSA_MIN','unitless',3100,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LATOSA_MIN','unitless',4500,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LATOSA_MIN','unitless',3900,'r5838',''],
             [20190405,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MIN','unitless',2000,'r5838',''],
             [20190405,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LATOSA_MIN','unitless',2000,'r5838',''],
             [20190405,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LATOSA_MIN','unitless',2000,'r5838',''],
             [20190405,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',3500,'r5838',''],
             [20190405,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LATOSA_MIN','unitless',3500,'r5838',''],
             [20190405,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',5000,'r5838',''],
             [20190405,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'TemperateBroadLeavedSummergreen','Residual','Temperate','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','SENESCENCE_TEMP_C','degrees C',12.5,'r5903',''],
             [20190405,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PSI_LEAF','MPa' ,-0.94,'r5903',''],
             [20190405,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PSI_LEAF','MPa' ,-0.94,'r5903',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','FRUIT_ALLOC','unitless',0.2,'r5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','FRUIT_ALLOC','unitless',0.2,'r5966',''],
             [20190516,'C4Agriculture','C4Agriculture','Temperate','FRUIT_ALLOC','unitless',0.2,'r5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','GDD_SENESCENCE','K',1600,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','GDD_SENESCENCE','K',2500,'r5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MIN','unitless',2,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MIN','unitless',2,'5966',''],
             [20190516,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',2,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MAX','unitless',2,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',2,'5966',''],
             [20190516,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',2,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','PHENO_GDD_CRIT_C','K',400,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','PHENO_GDD_CRIT_C','K',400,'5966',''],
             [20190516,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TAU_ROOT','days',280,'5966',''],
             [20190516,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','TAU_ROOT','days',280,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','TAU_ROOT','days',180,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','TAU_ROOT','days',180,'5966',''],
             [20190516,'C4Agriculture','C4Agriculture','Temperate','TAU_ROOT','days',180,'5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','SLAINIT','m2 gC-1',0.02,'r5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','SLAINIT','m2 gC-1',0.02,'r5966',''],
             [20190516,'C4Agriculture','C4Agriculture','Temperate','SLAINIT','m2 gC-1',0.02,'r5966',''],
             [20190516,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.165,'r5966',''],
             [20190516,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.340,'r5966',''],
             [20190516,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.135,'r5966',''],
             [20190516,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.135,'r5966',''],
             [20190516,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.135,'r5966',''],
             [20190516,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.135,'r5966',''],
             [20190516,'TemperateNeedleleafEvergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.135,'r5966',''],
             [20190516,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.200,'r5966',''],
             [20190516,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.200,'r5966',''],
             [20190516,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.280,'r5966',''],
             [20190516,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.280,'r5966',''],
             [20190516,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.280,'r5966',''],
             [20190516,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.280,'r5966',''],
             [20190516,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.280,'r5966',''],
             [20190516,'TemperateBroadLeavedSummergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.280,'r5966',''],
             [20190516,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.160,'r5966',''],
             [20190516,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.160,'r5966',''],
             [20190516,'BorealNeedleleafEvergreen','PiceaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.160,'r5966',''],
             [20190516,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.240,'r5966',''],
             [20190516,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.240,'r5966',''],
             [20190516,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.130,'r5966',''],
             [20190516,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.240,'r5966',''],
             [20190516,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.180,'r5966',''],
             [20190516,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.120,'r5966',''],
             [20190516,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.210,'r5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.180,'r5966',''],
             [20190516,'C3Agriculture','C3Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.160,'r5966',''],
             [20190516,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.160,'r5966',''],
             [20190606,'BareSoil','SoilBare','Global','PSI_ROOT','MPa',-9999.00,'r6002',''],
             [20190606,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateNeedleleafEvergreen','Residual','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'TemperateBroadLeavedSummergreen','Residual','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'BorealNeedleleafEvergreen','PiceaSp','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'BorealNeedleleafSummergreen','LarixSp','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C3Agriculture','C3Agriculture','Boreal','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C3Agriculture','C3Agriculture','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C4Agriculture','C4Agriculture','Temperate','PSI_ROOT','MPa',-5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','PHENO_MODEL','unitless','moigdd','r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','PHENO_MODEL','unitless','moigdd','r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','PHENO_MODEL','unitless','moigdd','r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','PHENO_MODEL','unitless','moigdd','r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','PHENO_TYPE','unitless',4,'r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','PHENO_TYPE','unitless',4,'r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','PHENO_TYPE','unitless',4,'r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','PHENO_TYPE','unitless',4,'r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','SENESCENCE_TYPE','unitless','mixed','r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','SENESCENCE_TYPE','unitless','mixed','r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','SENESCENCE_TYPE','unitless','mixed','r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','SENESCENCE_TYPE','unitless','mixed','r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','SENESCENCE_TEMP_C','degrees C',5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','SENESCENCE_TEMP_C','degrees C',5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','SENESCENCE_TEMP_C','degrees C',5.0,'r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','SENESCENCE_TEMP_C','degrees C',5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','NOSENESCENCE_HUM','unitless',0.3,'r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','NOSENESCENCE_HUM','unitless',0.3,'r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','NOSENESCENCE_HUM','unitless',0.3,'r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','NOSENESCENCE_HUM','unitless',0.3,'r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','TREE_FF','unitless',1.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','TREE_FF','unitless',1.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','TREE_FF','unitless',1.0,'r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','TREE_FF','unitless',1.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Boreal','LEAFFALL','days',5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Temperate','LEAFFALL','days',5.0,'r6002',''],
             [20190606,'C3Grass','C3Grass','Tropical','LEAFFALL','days',5.0,'r6002',''],
             [20190606,'C4Grass','C4Grass','Temperate','LEAFFALL','days',5.0,'r6002',''],
             [20190703,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.150,'r6093',''],
             [20190703,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TemperateNeedleleafEvergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.065,'r6093',''],
             [20190703,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.140,'r6093',''],
             [20190703,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.140,'r6093',''],
             [20190703,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.140,'r6093',''],
             [20190703,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.140,'r6093',''],
             [20190703,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.140,'r6093',''],
             [20190703,'TemperateBroadLeavedSummergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.140,'r6093',''],
             [20190703,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.120,'r6093',''],
             [20190703,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.120,'r6093',''],
             [20190703,'BorealNeedleleafEvergreen','PiceaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.120,'r6093',''],
             [20190703,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.130,'r6093',''],
             [20190703,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.130,'r6093',''],
             [20190703,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.130,'r6093',''],
             [20190703,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.04,'r6093',''],
             [20190703,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.04,'r6093',''],
             [20190703,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.04,'r6093',''],
             [20190703,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.04,'r6093',''],
             [20190703,'C3Agriculture','C3Agriculture','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.1090,'r6093',''],
             [20190703,'C3Agriculture','C3Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.190,'r6093',''],
             [20190703,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.240,'r6093',''],
             [20190705,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.08,'r6100',''],
             [20190705,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.14,'r6100',''],
             [20190705,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.076,'r6100',''],
             [20190705,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.076,'r6100',''],
             [20190705,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.076,'r6100',''],
             [20190705,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.076,'r6100',''],
             [20190705,'TemperateNeedleleafEvergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.076,'r6100',''],
             [20190705,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.063,'r6100',''],
             [20190705,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.063,'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.21,'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.21,'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.21,'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.21,'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.21,'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','Residual','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.21,'r6100',''],
             [20190705,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.14,'r6100',''],
             [20190705,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.14,'r6100',''],
             [20190705,'BorealNeedleleafEvergreen','PiceaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.14,'r6100',''],
             [20190705,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.40,'r6100',''],
             [20190705,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.40,'r6100',''],
             [20190705,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.19,'r6100',''],
             [20190705,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.12,'r6100',''],
             [20190705,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.08,'r6100',''],
             [20190705,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.04,'r6100',''],
             [20190705,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.10,'r6100',''],
             [20190705,'C3Agriculture','C3Agriculture','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.35,'r6100',''],
             [20190705,'C3Agriculture','C3Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.27,'r6100',''],
             [20190705,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.60,'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',4200, 'r6100',''],
             [20190705,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',4200, 'r6100',''],
             [20190705,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',4000,'r6100',''],
             [20190705,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',4000,'r6100',''],
             [20190705,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',1.6,'6100',''],
             [20190705,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',2.4,'6100',''],
             [20190705,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',1.6,'6100',''],
             [20190705,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',2.4,'6100',''],
             [20190829,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',4450,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_SELF_THINNING','unitless',435,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_SELF_THINNING','unitless',385,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_SELF_THINNING','unitless',720,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',836,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_SELF_THINNING','unitless',3700,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_SELF_THINNING','unitless',3785,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_SELF_THINNING','unitless',1400,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_SELF_THINNING','unitless',6000,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_SELF_THINNING','unitless',17470,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_SELF_THINNING','unitless',2827,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_SELF_THINNING','unitless',1050,'r6177','https://j-jeong.shinyapps.io/thinning/'],	
             [20190829,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_SELF_THINNING','unitless',3075,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_SELF_THINNING','unitless',7630,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_SELF_THINNING','unitless',1490,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_SELF_THINNING','unitless',640,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_SELF_THINNING','unitless',-0.37,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_SELF_THINNING','unitless',-0.35,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_SELF_THINNING','unitless',-0.43,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.48,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_SELF_THINNING','unitless',-0.67,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_SELF_THINNING','unitless',-0.72,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_SELF_THINNING','unitless',-0.54,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_SELF_THINNING','unitless',-0.74,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_SELF_THINNING','unitless',-0.93,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_SELF_THINNING','unitless',-0.73,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_SELF_THINNING','unitless',-0.57,'r6177','https://j-jeong.shinyapps.io/thinning/'],
	     [20190829,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_SELF_THINNING','unitless',-0.73,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_SELF_THINNING','unitless',-0.79,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_SELF_THINNING','unitless',-0.58,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_SELF_THINNING','unitless',-0.47,'r6177','https://j-jeong.shinyapps.io/thinning/'],
             [20190829,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','DIA_INIT_MAX','m',0.03,'r6177',''],
             [20190829,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','DIA_INIT_MAX','m',0.03,'r6177',''],
             [20191106,'C3Grass','C3Grass','Boreal','VCMAX25','umol m-2s-1',40,'r6294',''],
             [20191220,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PSI_LEAF','MPa',-1.91,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','PSI_LEAF','MPa',-2.15,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','PSI_LEAF','MPa',-2.94,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','Residual','Temperate','PSI_LEAF','MPa',-1.91,'r6417',''],
             [20191220,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateNeedleleafEvergreen','Residual','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20150303,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20191220,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-04,'r6417',''],
             [20200119,'C3Grass','C3Grass','Boreal','TREE_FF','unitless',1.0,'r6461',''],
             [20200119,'C3Grass','C3Grass','Temperate','TREE_FF','unitless',1.0,'r6461',''],
             [20200119,'C4Grass','C4Grass','Temperate','TREE_FF','unitless',1.0,'r6461',''],
             [20200119,'C3Agriculture','C3Agriculture','Boreal','TREE_FF','unitless',1.0,'r6461',''],
             [20200119,'C3Agriculture','C3Agriculture','Temperate','TREE_FF','unitless',1.0,'r6461',''],
             [20200119,'C4Agriculture','C4Agriculture','Temperate','TREE_FF','unitless',1.0,'r6461',''],
             [20200121,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',3000,'r6461',''],
             [20200121,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',3000,'r6461',''],
             [20200121,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',3000,'r6461',''],
             [20200121,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',3000,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MIN','unitless',6000,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MIN','unitless',6000,'r6461',''],
             [20200121,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',6000,'r6461',''],
             [20200121,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',3000,'r6461',''],
             [20200121,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',3000,'r6461',''],
             [20200121,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',3000,'r6461',''],
             [20200121,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',3000,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MAX','unitless',6000,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',6000,'r6461',''],
             [20200121,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',6000,'r6461',''],
             [20200121,'C3Grass','C3Grass','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-4,'r6461',''],
             [20200121,'C3Grass','C3Grass','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-4,'r6461',''],
             [20200121,'C3Grass','C3Grass','Tropical','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-4,'r6461',''],
             [20200121,'C4Grass','C4Grass','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-4,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Boreal','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-4,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-4,'r6461',''],
             [20200121,'C4Agriculture','C4Agriculture','Temperate','K_ROOT','m3 kg-1 s-1 MPa-1',7.02E-4,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Boreal','HEIGHT_INIT_MIN','m',0.2,'r6461',''],
             [20200121,'C3Agriculture','C3Agriculture','Temperate','HEIGHT_INIT_MIN','m',0.2,'r6461',''],
             [20200121,'C4Agriculture','C4Agriculture','Temperate','HEIGHT_INIT_MIN','m',0.2,'r6461',''],
             [20200122,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',2800,'r6470',''],
             [20200122,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',2800,'r6470',''],
             [20200122,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',3200,'r6470',''],
             [20200122,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',700,'r6470',''],
             [20200122,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',4200,'r6470',''],
             [20200122,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MIN','unitless',4000,'r6470',''],
             [20200122,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',4500,'r6470',''],
             [20200122,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',4500,'r6470',''],
             [20200122,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',2000,'r6470',''],
             [20200122,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',3000,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MIN','unitless',6000,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MIN','unitless',6000,'r6470',''],
             [20200122,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',6000,'r6470',''],
             [20200122,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',3000,'r6470',''],
             [20200122,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',1500,'r6470',''],
             [20200122,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',2800,'r6470',''],
             [20200122,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',2800,'r6470',''],
             [20200122,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',3200,'r6470',''],
             [20200122,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',700,'r6470',''],
             [20200122,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',4200,'r6470',''],
             [20200122,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',4000,'r6470',''],
             [20200122,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',4500,'r6470',''],
             [20200122,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',4500,'r6470',''],
             [20200122,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',2000,'r6470',''],
             [20200122,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',3000,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MAX','unitless',6000,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',6000,'r6470',''],
             [20200122,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',6000,'r6470',''],
             [20200122,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',3000,'r6470',''],
             [20200122,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',1500,'r6470',''],
             [20200122,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6E-7,'r6470',''],
             [20200122,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6E-7,'r6470',''],
             [20200122,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1E-7,'r6470',''],
             [20200122,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6E-7,'r6470',''],
             [20200122,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6E-7,'r6470',''],
             [20200122,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1.E-7,'r6470',''],
             [20200122,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1.4E-6,'r6470',''],
             [20200122,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',2.5E-7,'r6470',''],
             [20200122,'C3Grass','C3Grass','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.36E-6,'r6470',''],
             [20200122,'C4Grass','C4Grass','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.36E-6,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.36E-6,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.36E-6,'r6470',''],
             [20200122,'C4Agriculture','C4Agriculture','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.36E-6,'r6470',''],
             [20200122,'C3Grass','C3Grass','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.36E-6,'r6470',''],
             [20200122,'C3Grass','C3Grass','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.36E-6,'r6470',''],
             [20200122,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_SAP','m2 s-1MPa',2.E-3,'r6470',''],
             [20200122,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_SAP','m2 s-1MPa',2.E-3,'r6470',''],
             [20200122,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_SAP','m2 s-1MPa',1.1E-3,'r6470',''],
             [20200122,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_SAP','m2 s-1MPa',2.E-4,'r6470',''],
             [20200122,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_SAP','m2 s-1MPa',6.E-3,'r6470',''],
             [20200122,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_SAP','m2 s-1MPa',1.3E-3,'r6470',''],
             [20200122,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_SAP','m2 s-1MPa',6.E-3,'r6470',''],
             [20200122,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_SAP','m2 s-1MPa',1.2E-3,'r6470',''],
             [20200122,'C3Grass','C3Grass','Temperate','K_SAP','m2 s-1MPa',6.E-4,'r6470',''],
             [20200122,'C4Grass','C4Grass','Temperate','K_SAP','m2 s-1MPa',6.E-4,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Boreal','K_SAP','m2 s-1MPa',6.E-4,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Temperate','K_SAP','m2 s-1MPa',6.E-4,'r6470',''],
             [20200122,'C4Agriculture','C4Agriculture','Temperate','K_SAP','m2 s-1MPa',6.E-4,'r6470',''],
             [20200122,'C3Grass','C3Grass','Tropical','K_SAP','m2 s-1MPa',6.E-4,'r6470',''],
             [20200122,'C3Grass','C3Grass','Boreal','K_SAP','m2 s-1MPa',6.E-4,'r6470',''],
             [20200122,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TAU_ROOT','days',440,'r6470',''],
             [20200122,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TAU_ROOT','days',440,'r6470',''],
             [20200122,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TAU_ROOT','days',440,'r6470',''],
             [20200122,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TAU_ROOT','days',440,'r6470',''],
             [20200122,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TAU_ROOT','days',440,'r6470',''],
             [20200122,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TAU_ROOT','days',440,'r6470',''],
             [20200122,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TAU_ROOT','days',440,'r6470',''],
             [20200122,'BorealNeedleleafSummergreen','LarixSp','Boreal','TAU_ROOT','days',540,'r6470',''],
             [20200122,'C3Grass','C3Grass','Temperate','TAU_ROOT','days',440,'r6470',''],
             [20200122,'C4Grass','C4Grass','Temperate','TAU_ROOT','days',440,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Boreal','TAU_ROOT','days',360,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Temperate','TAU_ROOT','days',360,'r6470',''],
             [20200122,'C4Agriculture','C4Agriculture','Temperate','TAU_ROOT','days',360,'r6470',''],
             [20200122,'C3Grass','C3Grass','Tropical','TAU_ROOT','days',440,'r6470',''],
             [20200122,'C3Grass','C3Grass','Boreal','TAU_ROOT','days',440,'r6470',''],
             [20200122,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TAU_SAP','days',4800,'r6470',''],
             [20200122,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TAU_SAP','days',4800,'r6470',''],
             [20200122,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TAU_SAP','days',3600,'r6470',''],
             [20200122,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TAU_SAP','days',7200,'r6470',''],
             [20200122,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TAU_SAP','days',7200,'r6470',''],
             [20200122,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TAU_SAP','days',3600,'r6470',''],
             [20200122,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TAU_SAP','days',7200,'r6470',''],
             [20200122,'BorealNeedleleafSummergreen','LarixSp','Boreal','TAU_SAP','days',3600,'r6470',''],
             [20200122,'C3Grass','C3Grass','Temperate','TAU_SAP','days',480,'r6470',''],
             [20200122,'C4Grass','C4Grass','Temperate','TAU_SAP','days',480,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Boreal','TAU_SAP','days',480,'r6470',''],
             [20200122,'C3Agriculture','C3Agriculture','Temperate','TAU_SAP','days',480,'r6470',''],
             [20200122,'C4Agriculture','C4Agriculture','Temperate','TAU_SAP','days',480,'r6470',''],
             [20200122,'C3Grass','C3Grass','Tropical','TAU_SAP','days',480,'r6470',''],
             [20200122,'C3Grass','C3Grass','Boreal','TAU_SAP','days',480,'r6470',''],
             [20200122,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','PIPE_DENSITY','gC m-3',300000,'r6470',''],
             [20200122,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PIPE_TUNE2','m',25,'r6470',''],
             [20200122,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_TUNE2','m',25,'r6470',''],
             [20200122,'BorealNeedleleafSummergreen','LarixSp','Boreal','PIPE_TUNE2','m',22,'r6470',''],
             [20200328,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',1220,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_SELF_THINNING','unitless',395,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_SELF_THINNING','unitless',230,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_SELF_THINNING','unitless',550,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','Residual','Temperate','ALPHA_SELF_THINNING','unitless',1220,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',451,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_SELF_THINNING','unitless',451,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_SELF_THINNING','unitless',1167,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_SELF_THINNING','unitless',885,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_SELF_THINNING','unitless',484,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','ALPHA_SELF_THINNING','unitless',1092,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','ALPHA_SELF_THINNING','unitless',8590,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','Residual','Temperate','ALPHA_SELF_THINNING','unitless',1167,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_SELF_THINNING','unitless',2180,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_SELF_THINNING','unitless',780,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_SELF_THINNING','unitless',506,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_SELF_THINNING','unitless',1202,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_SELF_THINNING','unitless',427,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_SELF_THINNING','unitless',824,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.52,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_SELF_THINNING','unitless',-0.38,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_SELF_THINNING','unitless',-0.33,'r6681','tuned to avoid too high initial stand density'],
             [20200328,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_SELF_THINNING','unitless',-0.41,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateNeedleleafEvergreen','Residual','Temperate','BETA_SELF_THINNING','unitless',-0.52,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.42,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BETA_SELF_THINNING','unitless',-0.42,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_SELF_THINNING','unitless',-0.52,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_SELF_THINNING','unitless',-0.52,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_SELF_THINNING','unitless',-0.38,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_SELF_THINNING','unitless',-0.51,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_SELF_THINNING','unitless',-0.83,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'TemperateBroadLeavedSummergreen','Residual','Temperate','BETA_SELF_THINNING','unitless',-0.52,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_SELF_THINNING','unitless',-0.70,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_SELF_THINNING','unitless',-0.50,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_SELF_THINNING','unitless',-0.46,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_SELF_THINNING','unitless',-0.58,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_SELF_THINNING','unitless',-0.47,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200328,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_SELF_THINNING','unitless',-0.49,'r6681','https://j-jeong.shinyapps.io/thinning/'],
             [20200410,'C3Grass','C3Grass','Boreal','HARVEST_RATIO','unitless',0.5,'r6721','Externalized harvest_ratio for grasses see r6721'],
             [20200410,'C3Grass','C3Grass','Temperate','HARVEST_RATIO','unitless',0.5,'r6721','Externalized harvest_ratio for grasses see r6721'],
             [20200410,'C4Grass','C4Grass','Temperate','HARVEST_RATIO','unitless',0.5,'r6721','Externalized harvest_ratio for grasses see r6721'],
             [20200410,'C3Grass','C3Grass','Tropical','HARVEST_RATIO','unitless',0.5,'r6721','Externalized harvest_ratio for grasses see r6721'],
             [20200421,'BareSoil','SoilBare','Global','LONGEVITY_LEAF','days',-9999,'r6742','change parameter name not its value'],
             [20200421,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_LEAF','days',645,'r6742','change parameter name not its value'],
             [20200421,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_LEAF','days',231,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LONGEVITY_LEAF','days',1283,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LONGEVITY_LEAF','days',720,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LONGEVITY_LEAF','days',1670,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LONGEVITY_LEAF','days',1460,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','Residual','Temperate','LONGEVITY_LEAF','days',1283,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_LEAF','days',677,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LONGEVITY_LEAF','days',677,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_LEAF','days',146,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LONGEVITY_LEAF','days',146,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LONGEVITY_LEAF','days',183,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LONGEVITY_LEAF','days',183,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LONGEVITY_LEAF','days',183,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','Residual','Temperate','LONGEVITY_LEAF','days',146,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_LEAF','days',1660,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LONGEVITY_LEAF','days',1160,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LONGEVITY_LEAF','days',2160,'r6742','change parameter name not its value'],
             [20200421,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_LEAF','days',146,'r6742','change parameter name not its value'],
             [20200421,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LONGEVITY_LEAF','days',146,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_LEAF','days',180,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Boreal','LONGEVITY_LEAF','days',265,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Temperate','LONGEVITY_LEAF','days',200,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Tropical','LONGEVITY_LEAF','days',200,'r6742','change parameter name not its value'],  
             [20200421,'C4Grass','C4Grass','Temperate','LONGEVITY_LEAF','days',135,'r6742','change parameter name not its value'],
             [20200421,'C3Agriculture','C3Agriculture','Boreal','LONGEVITY_LEAF','days',1000,'r6742','change parameter name not its value'],
             [20200421,'C3Agriculture','C3Agriculture','Temperate','LONGEVITY_LEAF','days',1000,'r6742','change parameter name not its value'],
             [20200421,'C4Agriculture','C4Agriculture','Temperate','LONGEVITY_LEAF','days',1000,'r6742','change parameter name not its value'],
             [20200421,'BareSoil','SoilBare','Global','LONGEVITY_ROOT','days',-9999,'r6742','change parameter name not its value'],
             [20200421,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LONGEVITY_ROOT','days',224,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LONGEVITY_ROOT','days',275,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LONGEVITY_ROOT','days',326,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','Residual','Temperate','LONGEVITY_ROOT','days',275,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LONGEVITY_ROOT','days',280,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LONGEVITY_ROOT','days',280,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LONGEVITY_ROOT','days',280,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LONGEVITY_ROOT','days',280,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LONGEVITY_ROOT','days',280,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','Residual','Temperate','LONGEVITY_ROOT','days',280,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LONGEVITY_ROOT','days',224,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LONGEVITY_ROOT','days',368,'r6742','change parameter name not its value'],
             [20200421,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LONGEVITY_ROOT','days',280,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_ROOT','days',540,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Boreal','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Temperate','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'C4Grass','C4Grass','Temperate','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'C3Agriculture','C3Agriculture','Boreal','LONGEVITY_ROOT','days',360,'r6742','change parameter name not its value'],
             [20200421,'C3Agriculture','C3Agriculture','Temperate','LONGEVITY_ROOT','days',360,'r6742','change parameter name not its value'],
             [20190316,'C3Grass','C3Grass','Tropical','LONGEVITY_ROOT','days',440,'r6742','change parameter name not its value'],
             [20200421,'C4Agriculture','C4Agriculture','Temperate','LONGEVITY_ROOT','days',360,'r6742','change parameter name not its value'],
             [20200421,'BareSoil','SoilBare','Global','LONGEVITY_SAP' ,'days',-9999,'r6742','change parameter name not its value'],
             [20200421,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_SAP' ,'days',4800,'r6742','change parameter name not its value'],
             [20200421,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_SAP' ,'days',4800,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LONGEVITY_SAP' ,'days',3600,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LONGEVITY_SAP' ,'days',13870,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LONGEVITY_SAP' ,'days',15148,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LONGEVITY_SAP' ,'days',16425,'r6742','change parameter name not its value'],
             [20200421,'TemperateNeedleleafEvergreen','Residual','Temperate','LONGEVITY_SAP' ,'days',15148,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_SAP' ,'days',7200,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_SAP' ,'days',7200,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'TemperateBroadLeavedSummergreen','Residual','Temperate','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_SAP' ,'days',3600,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_SAP' ,'days',7200,'r6742','change parameter name not its value'],
             [20200421,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LONGEVITY_SAP' ,'days',11680,'r6742','change parameter name not its value'],
             [20200421,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_SAP' ,'days',3600,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Boreal','LONGEVITY_SAP' ,'days',480,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Temperate','LONGEVITY_SAP' ,'days',480,'r6742','change parameter name not its value'],
             [20200421,'C3Grass','C3Grass','Tropical','LONGEVITY_SAP','days',480,'r6742','change parameter name not its value'],
             [20200421,'C4Grass','C4Grass','Temperate','LONGEVITY_SAP' ,'days',480,'r6742','change parameter name not its value'],
             [20200421,'C3Agriculture','C3Agriculture','Boreal','LONGEVITY_SAP' ,'days',480,'r6742','change parameter name not its value'],
             [20200421,'C3Agriculture','C3Agriculture','Temperate','LONGEVITY_SAP' ,'days',480,'r6742','change parameter name not its value'],
             [20200421,'C4Agriculture','C4Agriculture','Temperate','LONGEVITY_SAP' ,'days',480,'r6742','change parameter name not its value'],
             [20200425,'C3Grass','C3Grass','Boreal','HEIGHT_INIT','m',0.3,'r6757','change parameter name not its value'],
             [20200425,'C3Grass','C3Grass','Temperate','HEIGHT_INIT','m',0.3,'r6757','change parameter name not its value'],
             [20200425,'C3Grass','C3Grass','Tropical','HEIGHT_INIT','m',0.3,'r6757','change parameter name not its value'],
             [20200425,'C4Grass','C4Grass','Temperate','HEIGHT_INIT','m',0.3,'r6757','change parameter name not its value'],
             [20200425,'C3Agriculture','C3Agriculture','Boreal','HEIGHT_INIT','m',0.2,'r6757','change parameter name not its value'],
             [20200425,'C3Agriculture','C3Agriculture','Temperate','HEIGHT_INIT','m',0.2,'r6757','change parameter name not its value'],
             [20200425,'C4Agriculture','C4Agriculture','Temperate','HEIGHT_INIT','m',0.2,'r6757','change parameter name not its value'],
             [20200430,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_SELF_THINNING' ,'days',3700,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','ALPHA_SELF_THINNING' ,'days',3700,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',4450,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','ALPHA_SELF_THINNING','unitless',2000,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','ALPHA_SELF_THINNING','unitless',2827,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_SELF_THINNING','unitless',1050,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_SELF_THINNING','unitless',7630,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BETA_SELF_THINNING' ,'days',-0.67,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','BETA_SELF_THINNING' ,'days',-0.67,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','BETA_SELF_THINNING','unitless',-0.67,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','BETA_SELF_THINNING','unitless',-0.73,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_SELF_THINNING','unitless',-0.57,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_SELF_THINNING','unitless',-0.79,'r6762','https://j-jeong.shinyapps.io/thinning/'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','NCDGDD_TEMP','unitless',-10.0,'r6762','Tuned to advance budbreak'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','NCDGDD_TEMP','unitless',-10.0,'r6762','Tuned to advance budbreak'],
             [20200430,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','SENESCENCE_TEMP_C','degrees C',12.0,'r6762','Tuned to advance senesence'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','SENESCENCE_TEMP_C','degrees C',12.0,'r6762','Tuned to advance senesence'],
             [20200430,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',3300,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',3100,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',2400,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',1450,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',5600,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MIN','unitless',4800,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',5500,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',9000,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',1200,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',1800,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',3000,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',1300,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MIN','unitless',6750,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',3000,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',3300,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',3100,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',2400,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',1450,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',5600,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',4800,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',5500,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',9000,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',1200,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',1800,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',3000,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',1300,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',6750,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',3000,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LEAFAGECRIT','days',200,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAFAGECRIT','days',220,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAFAGECRIT','days',220,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'C3Grass','C3Grass','Boreal','LEAFAGECRIT','days',220,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'C3Grass','C3Grass','Temperate','LEAFAGECRIT','days',200,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'C3Grass','C3Grass','Tropical','LEAFAGECRIT','days',180,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'C4Grass','C4Grass','Temperate','LEAFAGECRIT','days',200,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'C3Agriculture','C3Agriculture','Temperate','LEAFAGECRIT','days',200,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'C4Agriculture','C4Agriculture','Temperate','LEAFAGECRIT','days',200,'r6762','Couple leafagecrit to longevity_leaf'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PSI_LEAF','MPa' ,-2.2,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PSI_LEAF','MPa' ,-2.2,'r6762','Tuned to get acceptable GPP'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','PSI_LEAF','MPa' ,-3.0,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Boreal','PSI_LEAF','MPa' ,-3.0,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Temperate','PSI_LEAF','MPa' ,-3.0,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Grass','C3Grass','Tropical','PSI_LEAF','MPa' ,-3.0,'r6762','Tuned to get acceptable GPP'],
             [20200430,'C3Agriculture','C3Agriculture','Temperate','PSI_LEAF','MPa' ,-3.0,'r6762','Tuned to get acceptable GPP'],
             [20200430,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% turnover during growing season'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],
             [20200430,'C3Grass','C3Grass','Boreal','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],
             [20200430,'C3Grass','C3Grass','Temperate','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],
             [20200430,'C3Grass','C3Grass','Tropical','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],  
             [20200430,'C4Grass','C4Grass','Temperate','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],
             [20200430,'C3Agriculture','C3Agriculture','Boreal','LONGEVITY_LEAF','days',1000,'r6762','Tuned to have ~20% leaf turnover during growing season'],
             [20200430,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% turnover during growing season'],
             [20200430,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'C3Grass','C3Grass','Boreal','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'C3Grass','C3Grass','Temperate','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'C4Grass','C4Grass','Temperate','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'C3Agriculture','C3Agriculture','Boreal','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'C3Agriculture','C3Agriculture','Temperate','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20190316,'C3Grass','C3Grass','Tropical','LONGEVITY_ROOT','days',1000,'r5800','Tuned to have ~20% root turnover during growing season'],
             [20200430,'C4Agriculture','C4Agriculture','Temperate','LONGEVITY_ROOT','days',1000,'r6762','Tuned to have ~20% root turnover during growing season'],
             [20200430,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','DIA_INIT_MAX','m',0.05,'r6762','Increase canopy depth'],
             [20200430,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','DIA_INIT_MAX','m',0.05,'r6762','Increase canopy depth'],
             [20200528,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','ALPHA_SELF_THINNING','unitless',4450,'r6799','initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','ALPHA_SELF_THINNING','unitless',4450,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','ALPHA_SELF_THINNING','unitless',4450,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',1220,'r6799', 'manual tuning'],
             [20200528,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','ALPHA_SELF_THINNING','unitless',1220,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','ALPHA_SELF_THINNING','unitless',2000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','ALPHA_SELF_THINNING','unitless',2000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','ALPHA_SELF_THINNING','unitless',2827,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PiceaSp','Boreal','ALPHA_SELF_THINNING','unitless',2827,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','ALPHA_SELF_THINNING','unitless',1050,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6799','initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','Residual','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6799','initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6799', 'manual tuning'],
             [20200528,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','BETA_SELF_THINNING','unitless',-0.69,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','BETA_SELF_THINNING','unitless',-0.67,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','BETA_SELF_THINNING','unitless',-0.67,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','BETA_SELF_THINNING','unitless',-0.67,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','BETA_SELF_THINNING','unitless',-0.67,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','Residual','Temperate','BETA_SELF_THINNING','unitless',-0.67,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','BETA_SELF_THINNING','unitless',-0.73,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PiceaSp','Boreal','BETA_SELF_THINNING','unitless',-0.73,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','BETA_SELF_THINNING','unitless',-0.57,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1e-07,'r6799','initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','Residual','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1e-07,'r6799','initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.6e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1e-07,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1.4e-06,'r6799', 'initial guess based on value of MTC'],          
             [20200528,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LONGEVITY_LEAF','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LONGEVITY_LEAF','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LONGEVITY_LEAF','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LONGEVITY_LEAF','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','Residual','Temperate','LONGEVITY_LEAF','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LONGEVITY_LEAF','days',1660,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LONGEVITY_LEAF','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LONGEVITY_ROOT','days',1000,'r6799','initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateNeedleleafEvergreen','Residual','Temperate','LONGEVITY_ROOT','days',1000,'r6799','initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'TemperateBroadLeavedSummergreen','Residual','Temperate','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200528,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LONGEVITY_ROOT','days',1000,'r6799', 'initial guess based on value of MTC'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','ALPHA_SELF_THINNING','unitless',2827,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','BETA_SELF_THINNING','unitless',-0.73,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.14,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',5200,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',5200,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_SAP','m2 s-1MPa',0.0090,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_LEAF','days',730,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_SAP','days',7300,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_TUNE1','m',55,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_TUNE_EXP_COEFF','unitless',1.3,'r6810','initial guess based on other MTCs'],
             [20200613,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','SRL','m g-1',18.3,'r6810','initial guess based on other MTCs'],
             [20200613,'C3Grass','C3Grass','Tropical','LONGEVITY_ROOT','days',1000,'r6810','correction of typo'],
             [20200613,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'C3Grass','C3Grass','Boreal','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'C3Grass','C3Grass','Temperate','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'C3Grass','C3Grass','Tropical','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'C4Grass','C4Grass','Temperate','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'C3Agriculture','C3Agriculture','Temperate','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200613,'C4Agriculture','C4Agriculture','Temperate','SRL','m g-1',18.3,'r6810','changed to increase consistency between MTCs'],
             [20200703,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',4500,'r6825','manual tuning to stabelize LAI with time'],
             [20200703,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',4500,'r6825','manual tuning to stabelize LAI with time'],
             [20200703,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.17,'r6825','manual tuning to obtain acceptable NPP/GPP'],
             [20200707,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',3500,'r6829','initial guess following code revisions'],
             [20200707,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',3500,'r6829','initial guess following code revisions'],
             [20200917,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',6000,'r6871','Small tuning based on some literature values and tests'],
             [20200917,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MIN','unitless',6000,'r6871','Small tuning based on some literature values and tests'],
             [20200917,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.1,'r6871','Small tuning based on some literature values and tests'],
             [20200917,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAFAGECRIT','days',1810,'r6871','Small tuning based on some literature values and tests'],
             [20201002,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_LEAF','days',730,'r6884','initial guess following code revisions'],
             [20201002,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LONGEVITY_LEAF','days',910,'r6884','initial guess following code revisions'],
             [20201002,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','LONGEVITY_LEAF','days',910,'r6884','initial guess following code revisions'],
             [20201002,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','LONGEVITY_LEAF','days',910,'r6884','initial guess following code revisions'],
             [20201002,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','LONGEVITY_LEAF','days',910,'r6884','initial guess following code revisions'],
             [20201002,'TemperateNeedleleafEvergreen','Residual','Temperate','LONGEVITY_LEAF','days',910,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_LEAF','days',730,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','LONGEVITY_LEAF','days',730,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'TemperateBroadLeavedSummergreen','Residual','Temperate','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_LEAF','days',1810,'r6884','initial guess following code revisions'],
             [20201002,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','LONGEVITY_LEAF','days',1810,'r6884','initial guess following code revisions'],
             [20201002,'BorealNeedleleafEvergreen','PiceaSp','Boreal','LONGEVITY_LEAF','days',1810,'r6884','initial guess following code revisions'],
             [20201002,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_LEAF','days',220,'r6884','initial guess following code revisions'],
             [20201002,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_LEAF','days',220,'r6884','initial guess following code revisions'],
             [20201002,'C3Grass','C3Grass','Boreal','LONGEVITY_LEAF','days',220,'r6884','initial guess following code revisions'],
             [20201002,'C3Grass','C3Grass','Temperate','LONGEVITY_LEAF','days',200,'r6884','initial guess following code revisions'],
             [20201002,'C3Grass','C3Grass','Tropical','LONGEVITY_LEAF','days',180,'r6884','initial guess following code revisions'],
             [20201002,'C4Grass','C4Grass','Temperate','LONGEVITY_LEAF','days',200,'r6884','initial guess following code revisions'],
             [20201002,'C3Agriculture','C3Agriculture','Temperate','LONGEVITY_LEAF','days',200,'r6884','initial guess following code revisions'],
             [20201002,'C3Agriculture','C3Agriculture','Boreal','LONGEVITY_LEAF','days',90,'r6884','initial guess following code revisions'],
             [20201002,'C4Agriculture','C4Agriculture','Temperate','LONGEVITY_LEAF','days',200,'r6884','initial guess following code revisions'],
             [20201016,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',7000,'r6900','initial guess following code revisions'],
             [20201016,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',6000,'r6900','initial guess following code revisions'],
             [20201016,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',2000,'r6900','initial guess following code revisions'],
             [20201016,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',7000,'r6900','initial guess following code revisions'],
             [20201016,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',10000,'r6900','initial guess following code revisions'],
             [20201016,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',6000,'r6900','initial guess following code revisions'],
             [20201016,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',2600,'r6900','initial guess following code revisions'],
             [20201016,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',8000,'r6900','initial guess following code revisions'],
             [20201016,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',6000,'r6900','initial guess following code revisions'],
             [20201016,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',7000,'r6900','initial guess following code revisions'],
             [20201016,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',6000,'r6900','initial guess following code revisions'],
             [20201016,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',2000,'r6900','initial guess following code revisions'],
             [20201016,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',7000,'r6900','initial guess following code revisions'],
             [20201016,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',10000,'r6900','initial guess following code revisions'],
             [20201016,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',6000,'r6900','initial guess following code revisions'],
             [20201016,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',2600,'r6900','initial guess following code revisions'],
             [20201016,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MIN','unitless',8000,'r6900','initial guess following code revisions'],
             [20201016,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',8000,'r6900','initial guess following code revisions'],
             [20201016,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_LEAF','days',2000,'r6900','initial guess following code revisions'],
             [20201016,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_AGE_CRIT_TREF','degrees C',5,'r6900','initial guess following code revisions'],
             [20201016,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_AGE_CRIT_COEFF1','unitless',2,'r6900','initial guess following code revisions'],
             [20201016,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_AGE_CRIT_COEFF2','unitless',0.365,'r6900','initial guess following code revisions'],
             [20201016,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LEAF_AGE_CRIT_COEFF3','unitless',120,'r6900','initial guess following code revisions'],
             [20201023,'BorealNeedleleafSummergreen','LarixSp','Boreal','TPHOTO_MIN','degrees C',-20,'r6908','initial guess following code revisions'],
             [20201023,'BorealNeedleleafSummergreen','LarixSp','Boreal','NGD_CRIT','degrees C',5,'r6908','initial guess following code revisions'],
             [20201023,'BorealNeedleleafSummergreen','LarixSp','Boreal','LEAFFALL','days',25,'r6908','initial guess following code revisions'],
             [20201023,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',5000,'r6908','initial guess following code revisions'],
             [20201023,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',7000,'r6908', 'initial guess following code revisions'],
             [20201023,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',8000,'r6908','initial guess following code revisions'],
             [20201023,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',5000,'r6908','initial guess following code revisions'],
             [20201023,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',7000,'r6908', 'initial guess following code revisions'],
             [20201023,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',8000,'r6908','initial guess following code revisions'],
             [20201023,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_LEAF','days',180,'r6908','initial guess following code revisions'],
             [20201023,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_LEAF','days',180,'r6908','initial guess following code revisions'],
             [20201023,'C3Grass','C3Grass','Boreal','LONGEVITY_LEAF','days',180,'r6908','initial guess following code revisions'],
             [20201023,'C3Grass','C3Grass','Temperate','LONGEVITY_LEAF','days',220,'r6908','initial guess following code revisions'],
             [20201023,'C3Grass','C3Grass','Tropical','LONGEVITY_LEAF','days',220,'r6908','initial guess following code revisions'],
             [20201023,'C4Grass','C4Grass','Temperate','LONGEVITY_LEAF','days',220,'r6908','initial guess following code revisions'],
             [20201023,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.07,'r6908','initial guess following code revisions'],
             [20201023,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.08,'r6908','initial guess following code revisions'],
             [20201023,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.08,'r6908','initial guess following code revisions'],
             [20201023,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.35,'r6908','initial guess following code revisions'],
             [20201023,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.08,'r6908','initial guess following code revisions'],
             [20201023,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.02,'r6908','initial guess following code revisions'],
             [20201023,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC.gN.day-1',0.02,'r6908','initial guess following code revisions'],
             [20201023,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.02,'r6908','initial guess following code revisions'],
             [20201023,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC.gN.day-1',0.35,'r6908','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.060,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.130,'r6947','initial guess following code revisions'],
             [20201203,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.050,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.065,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.130,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.040,'r6947','initial guess following code revisions'],
             [20201203,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.160,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.160,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.110,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.070,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.100,'r6947','initial guess following code revisions'],
             [20201203,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.090,'r6947','initial guess following code revisions'],
             [20201203,'C3Agriculture','C3Agriculture','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.300,'r6947','initial guess following code revisions'],
             [20201203,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.300,'r6947','initial guess following code revisions'], 
             [20201203,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafSummergreen','LarixSp','Boreal','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Temperate','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C4Grass','C4Grass','Temperate','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Agriculture','C3Agriculture','Temperate','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C4Agriculture','C4Agriculture','Temperate','MAINT_RESP_SLOPE_A','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafSummergreen','LarixSp','Boreal','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Temperate','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C4Grass','C4Grass','Temperate','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Agriculture','C3Agriculture','Temperate','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C4Agriculture','C4Agriculture','Temperate','MAINT_RESP_SLOPE_B','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'BorealNeedleleafSummergreen','LarixSp','Boreal','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C4Grass','C4Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C3Agriculture','C3Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'C4Agriculture','C4Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.0,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',4250,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',4800,'r6947','initial guess following code revisions'],
             [20201203,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',3000,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',3000,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',1500,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',1500,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',3500,'r6947','initial guess following code revisions'],
             [20201203,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',1800,'r6947','initial guess following code revisions'],
             [20201203,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',8000,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',4250,'r6947','initial guess following code revisions'],
             [20201203,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',4800,'r6947','initial guess following code revisions'],
             [20201203,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',3000,'r6947','initial guess following code revisions'],
             [20201203,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',3000,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',1500,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',1500,'r6947','initial guess following code revisions'],
             [20201203,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',3500,'r6947','initial guess following code revisions'],
             [20201203,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',1800,'r6947','initial guess following code revisions'],
             [20201203,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',8000,'r6947','initial guess following code revisions'],
             [20201210,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'C3Agriculture','C3Agriculture','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r6956','initial guess following code revisions'],
             [20201210,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.02,'r6956','initial guess following code revisions'],
             [20201210,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.12,'r6956','initial guess following code revisions'],
             [20201210,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.03,'r6956','initial guess following code revisions'],
             [20201210,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.07,'r6956','initial guess following code revisions'],
             [20201210,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.18,'r6956','initial guess following code revisions'],
             [20201210,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.01,'r6956','initial guess following code revisions'],
             [20201210,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.32,'r6956','initial guess following code revisions'],
             [20201210,'BorealNeedleleafSummergreen','LarixSp','Boreal','MAINT_RESP_SLOPE_C','unitless',0.24,'r6956','initial guess following code revisions'],
             [20201210,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_C','unitless',0.16,'r6956','initial guess following code revisions'],
             [20201210,'C3Grass','C3Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.08,'r6956','initial guess following code revisions'],
             [20201210,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_C','unitless',0.12,'r6956','initial guess following code revisions'],
             [20201210,'C4Grass','C4Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.06,'r6956','initial guess following code revisions'],
             [20201210,'C3Agriculture','C3Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.46,'r6956','initial guess following code revisions'],
             [20201210,'C4Agriculture','C4Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.52,'r6956','initial guess following code revisions'],
             [20201222,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','ALPHA_SELF_THINNING','unitless',1348,'r6975','Manual tuning see ticket #743'],
             [20201222,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','BETA_SELF_THINNING','unitless',-0.57,'r6975','Manual tuning see ticket #743'],
             [20201222,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',6000,'r6977','Refined guess after global spinup'],
             [20201222,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',3600,'r6977','Refined guess after global spinup'],
             [20201222,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',8500,'r6977','Refined guess after global spinup'],
             [20201222,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',11500,'r6977','Refined guess after global spinup'], 
             [20201222,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',1100,'r6977','Refined guess after global spinup'],
             [20201222,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',1000,'r6977','Refined guess after global spinup'],
             [20201222,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',3000,'r6977','Refined guess after global spinup'],
             [20201222,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',1300,'r6977','Refined guess after global spinup'],
             [20201222,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',6000,'r6977','Refined guess after global spinup'],
             [20201222,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',3600,'r6977','Refined guess after global spinup'],
             [20201222,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',8500,'r6977','Refined guess after global spinup'],
             [20201222,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',11500,'r6977','Refined guess after global spinup'], 
             [20201222,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',1100,'r6977','Refined guess after global spinup'],
             [20201222,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',1000,'r6977','Refined guess after global spinup'],
             [20201222,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',3000,'r6977','Refined guess after global spinup'],
             [20201222,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',1300,'r6977','Refined guess after global spinup'],
             [20201222,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PERCENT_THROUGHFALL_PFT','percent',35,'r6977','Refined guess after global spinup'],
             [20201222,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PERCENT_THROUGHFALL_PFT','percent',35,'r6977','Refined guess after global spinup'],
             [20210216,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','ALPHA_SELF_THINNING','unitless',800,'r7065','Refined guess after global spinup'],
             [20210216,'BorealNeedleleafSummergreen','LarixSp','Boreal','ALPHA_SELF_THINNING','unitless',800,'r7065','Refined guess after global spinup'], 
             [20210216,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_SELF_THINNING','unitless',-0.56,'r7065','Refined guess after global spinup'],
             [20210216,'BorealNeedleleafSummergreen','LarixSp','Boreal','BETA_SELF_THINNING','unitless',-0.59,'r7065','Refined guess after global spinup'],
             [20210312,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1.02E-7,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1.5E-7,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',2.5E-8,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-8,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1E-7,'r7124','Manual tuning following r7124'],
             [20210312,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',8E-9,'r7124','Manual tuning following r7124'],
             [20210312,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-7,'r7124','Manual tuning following r7124'],
             [20210312,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',2.33E-8,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-7,'r7124','Manual tuning following r7124'],
             [20210312,'C4Grass','C4Grass','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-7,'r7124','Manual tuning following r7124'],
             [20210312,'C3Agriculture','C3Agriculture','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-7,'r7124','Manual tuning following r7124'],
             [20210312,'C4Agriculture','C4Agriculture','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-7,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-7,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4E-7,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',5000,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',4250,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',6000,'r7124','Manual tuning following r7124'],
             [20210312,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',7000,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','munitless',1400,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',5000,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',4250,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',6000,'r7124','Manual tuning following r7124'],
             [20210312,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',7000,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','munitless',1400,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'BorealNeedleleafSummergreen','LarixSp','Boreal','LABILE_RESERVE','gC m-2 gN-1 m2',2.0,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Temperate','LABILE_RESERVE','gC m-2 gN-1 m2',1.0,'r7124','Manual tuning following r7124'],
             [20210312,'C4Grass','C4Grass','Temperate','LABILE_RESERVE','gC m-2 gN-1 m2',1.0,'r7124','Manual tuning following r7124'],
             [20210312,'C3Agriculture','C3Agriculture','Temperate','LABILE_RESERVE','gC m-2 gN-1 m2',4.0,'r7124','Manual tuning following r7124'],
             [20210312,'C4Agriculture','C4Agriculture','Temperate','LABILE_RESERVE','gC m-2 gN-1 m2',4.0,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Tropical','LABILE_RESERVE','gC m-2 gN-1 m2',1.0,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Boreal','LABILE_RESERVE','gC m-2 gN-1 m2',1.0,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_ROOT','days',200,'r7124','Manual tuning following r7124'],
             [20210312,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_ROOT','days',200,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LONGEVITY_ROOT','days',300,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_ROOT','days',300,'r7124','Manual tuning following r7124'],
             [20210312,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_ROOT','days',300,'r7124','Manual tuning following r7124'],
             [20210312,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_ROOT','days',300,'r7124','Manual tuning following r7124'],
             [20210312,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_ROOT','days',300,'r7124','Manual tuning following r7124'],
             [20210312,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_ROOT','days',300,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Temperate','LONGEVITY_ROOT','days',100,'r7124','Manual tuning following r7124'],
             [20210312,'C4Grass','C4Grass','Temperate','LONGEVITY_ROOT','days',100,'r7124','Manual tuning following r7124'],
             [20210312,'C3Agriculture','C3Agriculture','Temperate','LONGEVITY_ROOT','days',100,'r7124','Manual tuning following r7124'],
             [20210312,'C4Agriculture','C4Agriculture','Temperate','LONGEVITY_ROOT','days',100,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Tropical','LONGEVITY_ROOT','days',80,'r7124','Manual tuning following r7124'],
             [20210312,'C3Grass','C3Grass','Boreal','LONGEVITY_ROOT','days',100,'r7124','Manual tuning following r7124'],
             [20210405,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.14,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.40,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.15,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.46,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.28,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.10,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.98,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'BorealNeedleleafSummergreen','LarixSp','Boreal','MAINT_RESP_SLOPE_C','unitless',0.78,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_C','unitless',1.18,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.40,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_C','unitless',0.48,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C4Grass','C4Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.68,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Agriculture','C3Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.50,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C4Agriculture','C4Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.58,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_SAP','days',3600,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_SAP','days',3600,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_SAP','days',1800,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_SAP','days',1800,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_SAP','days',2700,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Boreal','LONGEVITY_SAP','days',240,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Temperate','LONGEVITY_SAP','days',180,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Tropical','LONGEVITY_SAP','days',180,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C4Grass','C4Grass','Temperate','LONGEVITY_SAP','days',180,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Temperate','LONGEVITY_LEAF','days',180,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Tropical','LONGEVITY_LEAF','days',180,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C4Grass','C4Grass','Temperate','LONGEVITY_LEAF','days',180,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Tropical','LONGEVITY_ROOT','days',100,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',6200,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',7000,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',4500,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',4500,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',6000,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',2500,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',6200,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',7000,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',4500,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',4500,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',6000,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210405,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',2500,'r7134','initial guess following reduction in sugar loading to increase GPP'],
             [20210602,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',2E-7,'r7208','Enhancing consistency across PFTs'],
             [20210602,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3E-7,'r7208','Enhancing consistency across PFTs'],
             [20210602,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',2E-8,'r7208','Enhancing consistency across PFTs'],
             [20210602,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_SAP','days',3600,'r7208','Enhancing consistency across PFTs'],
             [20210602,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_SAP','days',3600,'r7208','Enhancing consistency across PFTs'],
             [20210602,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_SAP','days',3600,'r7208','Enhancing consistency across PFTs'],\
             [20210707,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.12,'r7244','initial guess following code revisions'],
             [20210707,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.32,'r7244','initial guess following code revisions'],
             [20210707,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.14,'r7244','initial guess following code revisions'],
             [20210707,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.12,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.13,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.06,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.07,'r7244','initial guess following code revisions'],
             [20210707,'C4Grass','C4Grass','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.05,'r7244','initial guess following code revisions'],
             [20210707,'C3Agriculture','C3Agriculture','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.05,'r7244','initial guess following code revisions'],
             [20210707,'C4Agriculture','C4Agriculture','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.08,'r7244','initial guess following code revisions'],
             [20210707,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',9200,'r7244','initial guess following code revisions'],
             [20210707,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',5600,'r7244','initial guess following code revisions'],
             [20210707,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',9000,'r7244','initial guess following code revisions'],
             [20210707,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.44,'r7244','initial guess following code revisions'],
             [20210707,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','MAINT_RESP_SLOPE_C','unitless',0.6,'r7244','initial guess following code revisions'],
             [20210707,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.2,'r7244','initial guess following code revisions'],
             [20210707,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.6,'r7244','initial guess following code revisions'],
             [20210707,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','MAINT_RESP_SLOPE_C','unitless',0.3,'r7244','initial guess following code revisions'],
             [20210707,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.3,'r7244','initial guess following code revisions'],
             [20210707,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.3,'r7244','initial guess following code revisions'],
             [20210707,'BorealNeedleleafSummergreen','LarixSp','Boreal','MAINT_RESP_SLOPE_C','unitless',0.4,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_C','unitless',0.75,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.5,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_C','unitless',0.55,'r7244','initial guess following code revisions'],
             [20210707,'C4Grass','C4Grass','Temperate','MAINT_RESP_SLOPE_C','unitless',0.5,'r7244','initial guess following code revisions'],
             [20210707,'C3Agriculture','C3Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.5,'r7244','initial guess following code revisions'],
             [20210707,'C4Agriculture','C4Agriculture','Temperate','MAINT_RESP_SLOPE_C','unitless',0.70,'r7244','initial guess following code revisions'],
             [20210707,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7244','initial guess following code revisions'],
             [20210707,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7244','initial guess following code revisions'],
             [20210707,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','MAINT_RESP_SLOPE_B','unitless',-0.04,'r7244','initial guess following code revisions'],
             [20210707,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','MAINT_RESP_SLOPE_B','unitless',-0.02,'r7244','initial guess following code revisions'],
             [20210707,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','MAINT_RESP_SLOPE_B','unitless',-0.02,'r7244','initial guess following code revisions'],
             [20210707,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7244','initial guess following code revisions'],
             [20210707,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_B','unitless',-0.03,'r7244','initial guess following code revisions'],
             [20210707,'BorealNeedleleafSummergreen','LarixSp','Boreal','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_B','unitless',-0.02,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Temperate','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7244','initial guess following code revisions'],
             [20210707,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7244','initial guess following code revisions'],
             [20210707,'C4Grass','C4Grass','Temperate','MAINT_RESP_SLOPE_B','unitless',-0.00,'r7244','initial guess following code revisions'],
             [20210707,'C3Agriculture','C3Agriculture','Temperate','MAINT_RESP_SLOPE_B','unitless',-0.00,'r7244','initial guess following code revisions'],
             [20210707,'C4Agriculture','C4Agriculture','Temperate','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7244','initial guess following code revisions'],
             [20210817,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',6200,'r7269','initial guess following code revisions'],
             [20210817,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',3600,'r7269','initial guess following code revisions'],
             [20210817,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',6000,'r7269','initial guess following code revisions'],
             [20210902,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',9200, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',7250, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LATOSA_MAX','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LATOSA_MAX','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LATOSA_MAX','unitless',6000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LATOSA_MAX','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',4500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LATOSA_MAX','unitless',4500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LATOSA_MAX','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LATOSA_MAX','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LATOSA_MAX','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LATOSA_MAX','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LATOSA_MAX','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LATOSA_MAX','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LATOSA_MAX','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',7000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LATOSA_MAX','unitless',7000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',11500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',10000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Grass','C3Grass','Temperate','K_LATOSA_MAX','unitless',7000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C4Grass','C4Grass','Temperate','K_LATOSA_MAX','unitless',5500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MAX','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MAX','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MAX','unitless',11000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',9200, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',7250, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','PinusSylvestris','Temperate','K_LATOSA_MIN','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','PinusPinaster','Temperate','K_LATOSA_MIN','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','PiceaSp','Temperate','K_LATOSA_MIN','unitless',6000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateNeedleleafEvergreen','Residual','Temperate','K_LATOSA_MIN','unitless',5600, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',4500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedEvergreen','QuercusIlexSuber','Temperate','K_LATOSA_MIN','unitless',4500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','BetulaSp','Temperate','K_LATOSA_MIN','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','FagusSylvatica','Temperate','K_LATOSA_MIN','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','QuercusRoburPetraea','Temperate','K_LATOSA_MIN','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','PopulusSp','Temperate','K_LATOSA_MIN','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'TemperateBroadLeavedSummergreen','Residual','Temperate','K_LATOSA_MIN','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MIN','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafEvergreen','PinusSylvestris','Boreal','K_LATOSA_MIN','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafEvergreen','PiceaSp','Boreal','K_LATOSA_MIN','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',7000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealBroadLeavedSummergreen','BetulaSp','Boreal','K_LATOSA_MIN','unitless',7000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',11500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',10000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Grass','C3Grass','Temperate','K_LATOSA_MIN','unitless',7000, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',8500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C4Grass','C4Grass','Temperate','K_LATOSA_MIN','unitless',5500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Agriculture','C3Agriculture','Boreal','K_LATOSA_MIN','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C3Agriculture','C3Agriculture','Temperate','K_LATOSA_MIN','unitless',9500, 'r7272','Manual tuning towards textbook knowledge'],
             [20210902,'C4Agriculture','C4Agriculture','Temperate','K_LATOSA_MIN','unitless',11000, 'r7272','Manual tuning towards textbook knowledge'],
             [20211123,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',6.6E-8,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',6.6E-8,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',8.0E-9,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',12,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',12,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',12,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',12,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',12,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211123,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',12,'r7355','Manual tuning to enhance match with ORC2 and ORC3'],
             [20211221,'C3Grass','C3Grass','Tropical','PHENO_MODEL','unitless','moi','r7355',''],
             [20220216,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','PIPE_TUNE2','m',55,'r7467','Manual tuning to get more realistic tree heights for tree with a diameter of 0.3 m'],
             [20220216,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','PIPE_TUNE2','m',55,'r7467','Manual tuning to get more realistic tree heights for tree with a diameter of 0.3 m'],
             [20220216,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','PIPE_TUNE2','m',45,'r7467','Manual tuning to get more realistic tree heights for tree with a diameter of 0.3 m'],
             [20220216,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','PIPE_TUNE2','m',50,'r7467','Manual tuning to get more realistic tree heights for tree with a diameter of 0.3 m'],
             [20220216,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','PIPE_TUNE2','m',30,'r7467','Manual tuning to get more realistic tree heights for tree with a diameter of 0.3 m'],
             [20220216,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_TUNE2','m',30,'r7467','Manual tuning to get more realistic tree heights for tree with a diameter of 0.3 m'],
             [20220216,'BorealNeedleleafSummergreen','LarixSp','Boreal','PIPE_TUNE2','m',30,'r7467','Manual tuning to get more realistic tree heights for tree with a diameter of 0.3 m'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',6159,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',7250,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MIN','unitless',5600,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MIN','unitless',2989,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',13890,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MIN','unitless',9120,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',5917,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MIN','unitless',15310,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',6159,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',7250,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',5600,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',2989,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',13890,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',9120,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',5917,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',15310,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',8.944e-8,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',6.6e-8,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',1.291e-8,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',4.04e-8,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',2.791e-7,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',5.254e-9,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.0e-7,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.287e-8,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',13.6,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',12.0,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',9.241,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',18.0,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',11.81,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',8.217,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',9.0,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',11.15,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',13.13,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',12.0,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',13.03,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',5.996,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',17.31,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',11.92,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',13.39,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',10.6,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.04531,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.04,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.07758,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.02938,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','COEFF_MAINT_INIT','gC gN-1 day-1',0.361,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.0318,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.1764,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.1072,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','SLAINIT','m2 gC-1',0.03963,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','SLAINIT','m2 gC-1',0.044,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','SLAINIT','m2 gC-1',0.01365,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','SLAINIT','m2 gC-1',0.02703,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SLAINIT','m2 gC-1',0.2377,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','SLAINIT','m2 gC-1',0.01886,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','SLAINIT','m2 gC-1',0.05749,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','SLAINIT','m2 gC-1',0.04164,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',14.08,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',30.0,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',20.79,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',19.95,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',56.61,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',20.59,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',38.0,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',27.75,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','TREE_FF','unitless',0.4681,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','TREE_FF','unitless',0.4234,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','TREE_FF','unitless',0.6,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','TREE_FF','unitless',0.6,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','TREE_FF','unitless',0.703,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','TREE_FF','unitless',0.7501,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','TREE_FF','unitless',0.7,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','TREE_FF','unitless',0.8187,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','LONGEVITY_SAP','days',7300,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','LONGEVITY_SAP','days',3766,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','LONGEVITY_SAP','days',3600,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','LONGEVITY_SAP','days',6643,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_SAP','days',3825,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','LONGEVITY_SAP','days',4046,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_SAP','days',4714,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','LONGEVITY_SAP','days',2140,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','A1','unitless',0.7401,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','A1','unitless',0.6305,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','A1','unitless',0.85,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','A1','unitless',0.9165,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','A1','unitless',0.502,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','A1','unitless',0.9419,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','A1','unitless',1.039,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','A1','unitless',0.783,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','B1','unitless',0.08582,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','B1','unitless',0.1943,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','B1','unitless',0.1705,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','B1','unitless',0.1501,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','B1','unitless',0.1949,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','B1','unitless',0.1071,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','B1','unitless',0.1486,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','B1','unitless',0.1798,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','B_RDI_LOWER_UNMAN','unitless',0.008182,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','B_RDI_LOWER_UNMAN','unitless',0.005369,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','B_RDI_LOWER_UNMAN','unitless',0.01843,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','B_RDI_LOWER_UNMAN','unitless',0.01658,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','B_RDI_LOWER_UNMAN','unitless',0.009738,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','B_RDI_LOWER_UNMAN','unitless',0.02402,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','B_RDI_LOWER_UNMAN','unitless',0.01992,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','B_RDI_LOWER_UNMAN','unitless',0.01066,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','B_RDI_UPPER_UNMAN','unitless',0.009082,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','B_RDI_UPPER_UNMAN','unitless',0.006269,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','B_RDI_UPPER_UNMAN','unitless',0.01933,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','B_RDI_UPPER_UNMAN','unitless',0.01748,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','B_RDI_UPPER_UNMAN','unitless',0.010638,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','B_RDI_UPPER_UNMAN','unitless',0.02492,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','B_RDI_UPPER_UNMAN','unitless',0.02082,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],
             [20220422,'BorealNeedleleafSummergreen','LarixSp','Boreal','B_RDI_UPPER_UNMAN','unitless',0.01156,'r7568','https://orchidas.lsce.ipsl.fr/dev/optim/opt-orc4d.php'],

             [20220524,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MIN','unitless',7500,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MIN','unitless',6000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MIN','unitless',15310,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MIN','unitless',15310,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TropicalBroadLeavedEvergreen','BroadLeavedEvergreen','Tropical','K_LATOSA_MAX','unitless',15000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TropicalBroadLeavedRaingreen','BroadLeavedRaingreen','Tropical','K_LATOSA_MAX','unitless',12000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','K_LATOSA_MAX','unitless',11000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','K_LATOSA_MAX','unitless',6000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LATOSA_MAX','unitless',30000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','K_LATOSA_MAX','unitless',18000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LATOSA_MAX','unitless',30000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealNeedleleafSummergreen','LarixSp','Boreal','K_LATOSA_MAX','unitless',30000,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateNeedleleafEvergreen','NeedleleafEvergreen','Temperate','RECRUITMENT_PFT','y/n','TRUE','r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedEvergreen','BroadLeavedEvergreen','Temperate','RECRUITMENT_PFT','y/n','TRUE','r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','RECRUITMENT_PFT','y/n','TRUE','r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealNeedleleafEvergreen','NeedleleafEvergreen','Boreal','RECRUITMENT_PFT','y/n','TRUE','r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','RECRUITMENT_PFT','y/n','TRUE','r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealNeedleleafSummergreen','LarixSp','Boreal','RECRUITMENT_PFT','y/n','TRUE','r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','BETA_SELF_THINNING','unitless',-0.59,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','B_RDI_LOWER_UNMAN','unitless',0.01066,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','B_RDI_UPPER_UNMAN','unitless',0.01156,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','COEFF_MAINT_INIT','gC.gN.day-1',0.1072,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.287e-07,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_LEAF','m s-1 MPa-1',2.5e-07,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','K_SAP','m2 s-1MPa',0.0012,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LEAFFALL','days',25,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','LONGEVITY_SAP','days',2140,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','MAINT_RESP_SLOPE_C','unitless',0.4,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','NUE_OPT','(mumol[CO2] s-1) (gN[leaf])-1',27.75,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','PIPE_TUNE3','unitless',0.52,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','SLAINIT','m2 gC-1',0.04164,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','VMAX_UPTAKE_NH4','umol g DryWeight_root-1 h-1',11.15,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'BorealBroadLeavedSummergreen','BroadLeavedSummergreen','Boreal','VMAX_UPTAKE_NO3','umol g DryWeight_root-1 h-1',10.6,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_BELOWGROUND','m3 kg-1 s-1 MPa-1',3.287e-07,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_LEAF','m s-1 MPa-1',2.5e-07,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','K_SAP','m2 s-1MPa',0.0012,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','LONGEVITY_SAP','days',2140,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','R_FROOT','m',0.00021,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220524,'TemperateBroadLeavedSummergreen','BroadLeavedSummergreen','Temperate','SLAINIT','m2 gC-1',0.05749,'r7615','Manual tuning to enhance long-term forest growth'],
             [20220714,'C3Grass','C3Grass','Tropical','ALPHA_LL','mol e- (mol photon)-1',0.3,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','ALPHA_LL','mol e- (mol photon)-1',0.43,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','COEFF_MAINT_INIT','gC gN-1 day-1',0.07,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','COEFF_MAINT_INIT','gC gN-1 day-1',0.13,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','IS_BOREAL','y/n','FALSE','r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','IS_BOREAL','y/n','TRUE','r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','IS_TEMPERATE','y/n','FALSE','r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','IS_TEMPERATE','y/n','FALSE','r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','LONGEVITY_SAP','days',180,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','LONGEVITY_SAP','days',240,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','K_LATOSA_MIN','unitless',8500,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','K_LATOSA_MIN','unitless',10000,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','K_LATOSA_MAX','unitless',8500,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','K_LATOSA_MAX','unitless',10000,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','PHENO_MODEL','unitless','moi','r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','PHENO_MODEL','unitless','moigdd','r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','HYDROL_HUMCSTE','unitless',4.0,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','HYDROL_HUMCSTE','unitless',0.6,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_B','unitless',-0.01,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_B','unitless',-0.02,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Tropical','MAINT_RESP_SLOPE_C','unitless',0.55,'r7690','copy of previous value to shorten run.def'],
             [20220714,'C3Grass','C3Grass','Boreal','MAINT_RESP_SLOPE_C','unitless',0.75,'r7690','copy of previous value to shorten run.def'],
\
]
